@@ -73,8 +73,8 @@ class BoreLSRPM(Bore):
         N=8,
         Rarc=0.0375,
         W1=0.0035,
-        alpha=0,
         type_merge_slot=1,
+        alpha=0,
         init_dict=None,
         init_str=None,
     ):
@@ -99,17 +99,16 @@ class BoreLSRPM(Bore):
                 Rarc = init_dict["Rarc"]
             if "W1" in list(init_dict.keys()):
                 W1 = init_dict["W1"]
-            if "alpha" in list(init_dict.keys()):
-                alpha = init_dict["alpha"]
             if "type_merge_slot" in list(init_dict.keys()):
                 type_merge_slot = init_dict["type_merge_slot"]
+            if "alpha" in list(init_dict.keys()):
+                alpha = init_dict["alpha"]
         # Set the properties (value check and convertion are done in setter)
         self.N = N
         self.Rarc = Rarc
         self.W1 = W1
-        self.alpha = alpha
         # Call Bore init
-        super(BoreLSRPM, self).__init__(type_merge_slot=type_merge_slot)
+        super(BoreLSRPM, self).__init__(type_merge_slot=type_merge_slot, alpha=alpha)
         # The class is frozen (in Bore init), for now it's impossible to
         # add new properties
 
@@ -122,7 +121,6 @@ class BoreLSRPM(Bore):
         BoreLSRPM_str += "N = " + str(self.N) + linesep
         BoreLSRPM_str += "Rarc = " + str(self.Rarc) + linesep
         BoreLSRPM_str += "W1 = " + str(self.W1) + linesep
-        BoreLSRPM_str += "alpha = " + str(self.alpha) + linesep
         return BoreLSRPM_str
 
     def __eq__(self, other):
@@ -140,8 +138,6 @@ class BoreLSRPM(Bore):
             return False
         if other.W1 != self.W1:
             return False
-        if other.alpha != self.alpha:
-            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None, is_add_value=False):
@@ -193,21 +189,6 @@ class BoreLSRPM(Bore):
                 diff_list.append(name + ".W1" + val_str)
             else:
                 diff_list.append(name + ".W1")
-        if (
-            other._alpha is not None
-            and self._alpha is not None
-            and isnan(other._alpha)
-            and isnan(self._alpha)
-        ):
-            pass
-        elif other._alpha != self._alpha:
-            if is_add_value:
-                val_str = (
-                    " (self=" + str(self._alpha) + ", other=" + str(other._alpha) + ")"
-                )
-                diff_list.append(name + ".alpha" + val_str)
-            else:
-                diff_list.append(name + ".alpha")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -222,7 +203,6 @@ class BoreLSRPM(Bore):
         S += getsizeof(self.N)
         S += getsizeof(self.Rarc)
         S += getsizeof(self.W1)
-        S += getsizeof(self.alpha)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -245,7 +225,6 @@ class BoreLSRPM(Bore):
         BoreLSRPM_dict["N"] = self.N
         BoreLSRPM_dict["Rarc"] = self.Rarc
         BoreLSRPM_dict["W1"] = self.W1
-        BoreLSRPM_dict["alpha"] = self.alpha
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         BoreLSRPM_dict["__class__"] = "BoreLSRPM"
@@ -258,15 +237,15 @@ class BoreLSRPM(Bore):
         N_val = self.N
         Rarc_val = self.Rarc
         W1_val = self.W1
-        alpha_val = self.alpha
         type_merge_slot_val = self.type_merge_slot
+        alpha_val = self.alpha
         # Creates new object of the same type with the copied properties
         obj_copy = type(self)(
             N=N_val,
             Rarc=Rarc_val,
             W1=W1_val,
-            alpha=alpha_val,
             type_merge_slot=type_merge_slot_val,
+            alpha=alpha_val,
         )
         return obj_copy
 
@@ -276,7 +255,6 @@ class BoreLSRPM(Bore):
         self.N = None
         self.Rarc = None
         self.W1 = None
-        self.alpha = None
         # Set to None the properties inherited from Bore
         super(BoreLSRPM, self)._set_None()
 
@@ -335,21 +313,3 @@ class BoreLSRPM(Bore):
         :Type: float
         """,
     )
-
-    def _get_alpha(self):
-        """getter of alpha"""
-        return self._alpha
-
-    def _set_alpha(self, value):
-        """setter of alpha"""
-        check_var("alpha", value, "float")
-        self._alpha = value
-
-    alpha = property(
-        fget=_get_alpha,
-        fset=_set_alpha,
-        doc=u"""Angular offset
-
-        :Type: float
-        """,
-    )
