@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Elmer import Elmer
 
 # Import all class method
@@ -33,6 +33,7 @@ except ImportError as error:
     get_data = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -73,9 +74,8 @@ class ElmerResults(Elmer):
         )
     else:
         get_data = get_data
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -172,7 +172,7 @@ class ElmerResults(Elmer):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -182,17 +182,63 @@ class ElmerResults(Elmer):
         diff_list = list()
 
         # Check the properties inherited from Elmer
-        diff_list.extend(super(ElmerResults, self).compare(other, name=name))
+        diff_list.extend(
+            super(ElmerResults, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._data != self._data:
-            diff_list.append(name + ".data")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._data) + ", other=" + str(other._data) + ")"
+                )
+                diff_list.append(name + ".data" + val_str)
+            else:
+                diff_list.append(name + ".data")
         if other._file != self._file:
-            diff_list.append(name + ".file")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._file) + ", other=" + str(other._file) + ")"
+                )
+                diff_list.append(name + ".file" + val_str)
+            else:
+                diff_list.append(name + ".file")
         if other._usecols != self._usecols:
-            diff_list.append(name + ".usecols")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._usecols)
+                    + ", other="
+                    + str(other._usecols)
+                    + ")"
+                )
+                diff_list.append(name + ".usecols" + val_str)
+            else:
+                diff_list.append(name + ".usecols")
         if other._columns != self._columns:
-            diff_list.append(name + ".columns")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._columns)
+                    + ", other="
+                    + str(other._columns)
+                    + ")"
+                )
+                diff_list.append(name + ".columns" + val_str)
+            else:
+                diff_list.append(name + ".columns")
         if other._is_scalars != self._is_scalars:
-            diff_list.append(name + ".is_scalars")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_scalars)
+                    + ", other="
+                    + str(other._is_scalars)
+                    + ")"
+                )
+                diff_list.append(name + ".is_scalars" + val_str)
+            else:
+                diff_list.append(name + ".is_scalars")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -248,6 +294,36 @@ class ElmerResults(Elmer):
         ElmerResults_dict["__class__"] = "ElmerResults"
         return ElmerResults_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.data is None:
+            data_val = None
+        else:
+            data_val = self.data.copy()
+        file_val = self.file
+        if self.usecols is None:
+            usecols_val = None
+        else:
+            usecols_val = self.usecols.copy()
+        if self.columns is None:
+            columns_val = None
+        else:
+            columns_val = self.columns.copy()
+        is_scalars_val = self.is_scalars
+        logger_name_val = self.logger_name
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            data=data_val,
+            file=file_val,
+            usecols=usecols_val,
+            columns=columns_val,
+            is_scalars=is_scalars_val,
+            logger_name=logger_name_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
