@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 # Import all class method
@@ -23,8 +23,8 @@ except ImportError as error:
     get_data = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Import import Import
 
 
 class ImportData(FrozenClass):
@@ -41,9 +41,8 @@ class ImportData(FrozenClass):
         )
     else:
         get_data = get_data
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -147,7 +146,7 @@ class ImportData(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -167,7 +166,10 @@ class ImportData(FrozenClass):
             for ii in range(len(other.axes)):
                 diff_list.extend(
                     self.axes[ii].compare(
-                        other.axes[ii], name=name + ".axes[" + str(ii) + "]"
+                        other.axes[ii],
+                        name=name + ".axes[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if (other.field is None and self.field is not None) or (
@@ -175,17 +177,66 @@ class ImportData(FrozenClass):
         ):
             diff_list.append(name + ".field None mismatch")
         elif self.field is not None:
-            diff_list.extend(self.field.compare(other.field, name=name + ".field"))
+            diff_list.extend(
+                self.field.compare(
+                    other.field,
+                    name=name + ".field",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         if other._unit != self._unit:
-            diff_list.append(name + ".unit")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._unit) + ", other=" + str(other._unit) + ")"
+                )
+                diff_list.append(name + ".unit" + val_str)
+            else:
+                diff_list.append(name + ".unit")
         if other._name != self._name:
-            diff_list.append(name + ".name")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._name) + ", other=" + str(other._name) + ")"
+                )
+                diff_list.append(name + ".name" + val_str)
+            else:
+                diff_list.append(name + ".name")
         if other._symbol != self._symbol:
-            diff_list.append(name + ".symbol")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._symbol)
+                    + ", other="
+                    + str(other._symbol)
+                    + ")"
+                )
+                diff_list.append(name + ".symbol" + val_str)
+            else:
+                diff_list.append(name + ".symbol")
         if other._normalizations != self._normalizations:
-            diff_list.append(name + ".normalizations")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._normalizations)
+                    + ", other="
+                    + str(other._normalizations)
+                    + ")"
+                )
+                diff_list.append(name + ".normalizations" + val_str)
+            else:
+                diff_list.append(name + ".normalizations")
         if other._symmetries != self._symmetries:
-            diff_list.append(name + ".symmetries")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._symmetries)
+                    + ", other="
+                    + str(other._symmetries)
+                    + ")"
+                )
+                diff_list.append(name + ".symmetries" + val_str)
+            else:
+                diff_list.append(name + ".symmetries")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -257,6 +308,43 @@ class ImportData(FrozenClass):
         ImportData_dict["__class__"] = "ImportData"
         return ImportData_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.axes is None:
+            axes_val = None
+        else:
+            axes_val = list()
+            for obj in self.axes:
+                axes_val.append(obj.copy())
+        if self.field is None:
+            field_val = None
+        else:
+            field_val = self.field.copy()
+        unit_val = self.unit
+        name_val = self.name
+        symbol_val = self.symbol
+        if self.normalizations is None:
+            normalizations_val = None
+        else:
+            normalizations_val = self.normalizations.copy()
+        if self.symmetries is None:
+            symmetries_val = None
+        else:
+            symmetries_val = self.symmetries.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            axes=axes_val,
+            field=field_val,
+            unit=unit_val,
+            name=name_val,
+            symbol=symbol_val,
+            normalizations=normalizations_val,
+            symmetries=symmetries_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -281,6 +369,15 @@ class ImportData(FrozenClass):
         """setter of axes"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "axes"
@@ -309,13 +406,20 @@ class ImportData(FrozenClass):
     def _set_field(self, value):
         """setter of field"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "field"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Import = import_class("pyleecan.Classes", "Import", "field")
             value = Import()
         check_var("field", value, "Import")
         self._field = value
