@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .ImportMatrix import ImportMatrix
 
 # Import all class method
@@ -22,7 +22,23 @@ try:
 except ImportError as error:
     get_data = error
 
+try:
+    from ..Methods.Import.ImportGenPWM.comp_voltage import comp_voltage
+except ImportError as error:
+    comp_voltage = error
 
+try:
+    from ..Methods.Import.ImportGenPWM.get_modulation_index import get_modulation_index
+except ImportError as error:
+    get_modulation_index = error
+
+try:
+    from ..Methods.Import.ImportGenPWM.comp_carrier import comp_carrier
+except ImportError as error:
+    comp_carrier = error
+
+
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -31,6 +47,7 @@ class ImportGenPWM(ImportMatrix):
 
     VERSION = 1
 
+    # Check ImportError to remove unnecessary dependencies in unused method
     # cf Methods.Import.ImportGenPWM.get_data
     if isinstance(get_data, ImportError):
         get_data = property(
@@ -40,9 +57,42 @@ class ImportGenPWM(ImportMatrix):
         )
     else:
         get_data = get_data
-    # save and copy methods are available in all object
+    # cf Methods.Import.ImportGenPWM.comp_voltage
+    if isinstance(comp_voltage, ImportError):
+        comp_voltage = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use ImportGenPWM method comp_voltage: " + str(comp_voltage)
+                )
+            )
+        )
+    else:
+        comp_voltage = comp_voltage
+    # cf Methods.Import.ImportGenPWM.get_modulation_index
+    if isinstance(get_modulation_index, ImportError):
+        get_modulation_index = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use ImportGenPWM method get_modulation_index: "
+                    + str(get_modulation_index)
+                )
+            )
+        )
+    else:
+        get_modulation_index = get_modulation_index
+    # cf Methods.Import.ImportGenPWM.comp_carrier
+    if isinstance(comp_carrier, ImportError):
+        comp_carrier = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use ImportGenPWM method comp_carrier: " + str(comp_carrier)
+                )
+            )
+        )
+    else:
+        comp_carrier = comp_carrier
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -58,12 +108,14 @@ class ImportGenPWM(ImportMatrix):
         fswi_max=3000,
         typePWM=8,
         Vdc1=2,
-        U0=1,
+        U0=None,
         type_carrier=0,
         var_amp=20,
         qs=3,
         is_star=True,
-        rot_dir=-1,
+        phase_dir=-1,
+        current_dir=-1,
+        Phi0=0,
         is_transpose=False,
         init_dict=None,
         init_str=None,
@@ -113,8 +165,12 @@ class ImportGenPWM(ImportMatrix):
                 qs = init_dict["qs"]
             if "is_star" in list(init_dict.keys()):
                 is_star = init_dict["is_star"]
-            if "rot_dir" in list(init_dict.keys()):
-                rot_dir = init_dict["rot_dir"]
+            if "phase_dir" in list(init_dict.keys()):
+                phase_dir = init_dict["phase_dir"]
+            if "current_dir" in list(init_dict.keys()):
+                current_dir = init_dict["current_dir"]
+            if "Phi0" in list(init_dict.keys()):
+                Phi0 = init_dict["Phi0"]
             if "is_transpose" in list(init_dict.keys()):
                 is_transpose = init_dict["is_transpose"]
         # Set the properties (value check and convertion are done in setter)
@@ -133,7 +189,9 @@ class ImportGenPWM(ImportMatrix):
         self.var_amp = var_amp
         self.qs = qs
         self.is_star = is_star
-        self.rot_dir = rot_dir
+        self.phase_dir = phase_dir
+        self.current_dir = current_dir
+        self.Phi0 = Phi0
         # Call ImportMatrix init
         super(ImportGenPWM, self).__init__(is_transpose=is_transpose)
         # The class is frozen (in ImportMatrix init), for now it's impossible to
@@ -160,7 +218,9 @@ class ImportGenPWM(ImportMatrix):
         ImportGenPWM_str += "var_amp = " + str(self.var_amp) + linesep
         ImportGenPWM_str += "qs = " + str(self.qs) + linesep
         ImportGenPWM_str += "is_star = " + str(self.is_star) + linesep
-        ImportGenPWM_str += "rot_dir = " + str(self.rot_dir) + linesep
+        ImportGenPWM_str += "phase_dir = " + str(self.phase_dir) + linesep
+        ImportGenPWM_str += "current_dir = " + str(self.current_dir) + linesep
+        ImportGenPWM_str += "Phi0 = " + str(self.Phi0) + linesep
         return ImportGenPWM_str
 
     def __eq__(self, other):
@@ -202,11 +262,15 @@ class ImportGenPWM(ImportMatrix):
             return False
         if other.is_star != self.is_star:
             return False
-        if other.rot_dir != self.rot_dir:
+        if other.phase_dir != self.phase_dir:
+            return False
+        if other.current_dir != self.current_dir:
+            return False
+        if other.Phi0 != self.Phi0:
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -216,39 +280,246 @@ class ImportGenPWM(ImportMatrix):
         diff_list = list()
 
         # Check the properties inherited from ImportMatrix
-        diff_list.extend(super(ImportGenPWM, self).compare(other, name=name))
-        if other._fs != self._fs:
-            diff_list.append(name + ".fs")
-        if other._duration != self._duration:
-            diff_list.append(name + ".duration")
-        if other._f != self._f:
-            diff_list.append(name + ".f")
-        if other._fmax != self._fmax:
-            diff_list.append(name + ".fmax")
+        diff_list.extend(
+            super(ImportGenPWM, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._fs is not None
+            and self._fs is not None
+            and isnan(other._fs)
+            and isnan(self._fs)
+        ):
+            pass
+        elif other._fs != self._fs:
+            if is_add_value:
+                val_str = " (self=" + str(self._fs) + ", other=" + str(other._fs) + ")"
+                diff_list.append(name + ".fs" + val_str)
+            else:
+                diff_list.append(name + ".fs")
+        if (
+            other._duration is not None
+            and self._duration is not None
+            and isnan(other._duration)
+            and isnan(self._duration)
+        ):
+            pass
+        elif other._duration != self._duration:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._duration)
+                    + ", other="
+                    + str(other._duration)
+                    + ")"
+                )
+                diff_list.append(name + ".duration" + val_str)
+            else:
+                diff_list.append(name + ".duration")
+        if (
+            other._f is not None
+            and self._f is not None
+            and isnan(other._f)
+            and isnan(self._f)
+        ):
+            pass
+        elif other._f != self._f:
+            if is_add_value:
+                val_str = " (self=" + str(self._f) + ", other=" + str(other._f) + ")"
+                diff_list.append(name + ".f" + val_str)
+            else:
+                diff_list.append(name + ".f")
+        if (
+            other._fmax is not None
+            and self._fmax is not None
+            and isnan(other._fmax)
+            and isnan(self._fmax)
+        ):
+            pass
+        elif other._fmax != self._fmax:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._fmax) + ", other=" + str(other._fmax) + ")"
+                )
+                diff_list.append(name + ".fmax" + val_str)
+            else:
+                diff_list.append(name + ".fmax")
         if other._fmode != self._fmode:
-            diff_list.append(name + ".fmode")
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._fmode) + ", other=" + str(other._fmode) + ")"
+                )
+                diff_list.append(name + ".fmode" + val_str)
+            else:
+                diff_list.append(name + ".fmode")
         if other._fswimode != self._fswimode:
-            diff_list.append(name + ".fswimode")
-        if other._fswi != self._fswi:
-            diff_list.append(name + ".fswi")
-        if other._fswi_max != self._fswi_max:
-            diff_list.append(name + ".fswi_max")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._fswimode)
+                    + ", other="
+                    + str(other._fswimode)
+                    + ")"
+                )
+                diff_list.append(name + ".fswimode" + val_str)
+            else:
+                diff_list.append(name + ".fswimode")
+        if (
+            other._fswi is not None
+            and self._fswi is not None
+            and isnan(other._fswi)
+            and isnan(self._fswi)
+        ):
+            pass
+        elif other._fswi != self._fswi:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._fswi) + ", other=" + str(other._fswi) + ")"
+                )
+                diff_list.append(name + ".fswi" + val_str)
+            else:
+                diff_list.append(name + ".fswi")
+        if (
+            other._fswi_max is not None
+            and self._fswi_max is not None
+            and isnan(other._fswi_max)
+            and isnan(self._fswi_max)
+        ):
+            pass
+        elif other._fswi_max != self._fswi_max:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._fswi_max)
+                    + ", other="
+                    + str(other._fswi_max)
+                    + ")"
+                )
+                diff_list.append(name + ".fswi_max" + val_str)
+            else:
+                diff_list.append(name + ".fswi_max")
         if other._typePWM != self._typePWM:
-            diff_list.append(name + ".typePWM")
-        if other._Vdc1 != self._Vdc1:
-            diff_list.append(name + ".Vdc1")
-        if other._U0 != self._U0:
-            diff_list.append(name + ".U0")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._typePWM)
+                    + ", other="
+                    + str(other._typePWM)
+                    + ")"
+                )
+                diff_list.append(name + ".typePWM" + val_str)
+            else:
+                diff_list.append(name + ".typePWM")
+        if (
+            other._Vdc1 is not None
+            and self._Vdc1 is not None
+            and isnan(other._Vdc1)
+            and isnan(self._Vdc1)
+        ):
+            pass
+        elif other._Vdc1 != self._Vdc1:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Vdc1) + ", other=" + str(other._Vdc1) + ")"
+                )
+                diff_list.append(name + ".Vdc1" + val_str)
+            else:
+                diff_list.append(name + ".Vdc1")
+        if (
+            other._U0 is not None
+            and self._U0 is not None
+            and isnan(other._U0)
+            and isnan(self._U0)
+        ):
+            pass
+        elif other._U0 != self._U0:
+            if is_add_value:
+                val_str = " (self=" + str(self._U0) + ", other=" + str(other._U0) + ")"
+                diff_list.append(name + ".U0" + val_str)
+            else:
+                diff_list.append(name + ".U0")
         if other._type_carrier != self._type_carrier:
-            diff_list.append(name + ".type_carrier")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._type_carrier)
+                    + ", other="
+                    + str(other._type_carrier)
+                    + ")"
+                )
+                diff_list.append(name + ".type_carrier" + val_str)
+            else:
+                diff_list.append(name + ".type_carrier")
         if other._var_amp != self._var_amp:
-            diff_list.append(name + ".var_amp")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._var_amp)
+                    + ", other="
+                    + str(other._var_amp)
+                    + ")"
+                )
+                diff_list.append(name + ".var_amp" + val_str)
+            else:
+                diff_list.append(name + ".var_amp")
         if other._qs != self._qs:
-            diff_list.append(name + ".qs")
+            if is_add_value:
+                val_str = " (self=" + str(self._qs) + ", other=" + str(other._qs) + ")"
+                diff_list.append(name + ".qs" + val_str)
+            else:
+                diff_list.append(name + ".qs")
         if other._is_star != self._is_star:
-            diff_list.append(name + ".is_star")
-        if other._rot_dir != self._rot_dir:
-            diff_list.append(name + ".rot_dir")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_star)
+                    + ", other="
+                    + str(other._is_star)
+                    + ")"
+                )
+                diff_list.append(name + ".is_star" + val_str)
+            else:
+                diff_list.append(name + ".is_star")
+        if other._phase_dir != self._phase_dir:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._phase_dir)
+                    + ", other="
+                    + str(other._phase_dir)
+                    + ")"
+                )
+                diff_list.append(name + ".phase_dir" + val_str)
+            else:
+                diff_list.append(name + ".phase_dir")
+        if other._current_dir != self._current_dir:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._current_dir)
+                    + ", other="
+                    + str(other._current_dir)
+                    + ")"
+                )
+                diff_list.append(name + ".current_dir" + val_str)
+            else:
+                diff_list.append(name + ".current_dir")
+        if (
+            other._Phi0 is not None
+            and self._Phi0 is not None
+            and isnan(other._Phi0)
+            and isnan(self._Phi0)
+        ):
+            pass
+        elif other._Phi0 != self._Phi0:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._Phi0) + ", other=" + str(other._Phi0) + ")"
+                )
+                diff_list.append(name + ".Phi0" + val_str)
+            else:
+                diff_list.append(name + ".Phi0")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -275,7 +546,9 @@ class ImportGenPWM(ImportMatrix):
         S += getsizeof(self.var_amp)
         S += getsizeof(self.qs)
         S += getsizeof(self.is_star)
-        S += getsizeof(self.rot_dir)
+        S += getsizeof(self.phase_dir)
+        S += getsizeof(self.current_dir)
+        S += getsizeof(self.Phi0)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -310,12 +583,61 @@ class ImportGenPWM(ImportMatrix):
         ImportGenPWM_dict["var_amp"] = self.var_amp
         ImportGenPWM_dict["qs"] = self.qs
         ImportGenPWM_dict["is_star"] = self.is_star
-        ImportGenPWM_dict["rot_dir"] = self.rot_dir
+        ImportGenPWM_dict["phase_dir"] = self.phase_dir
+        ImportGenPWM_dict["current_dir"] = self.current_dir
+        ImportGenPWM_dict["Phi0"] = self.Phi0
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         ImportGenPWM_dict["__class__"] = "ImportGenPWM"
         return ImportGenPWM_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        fs_val = self.fs
+        duration_val = self.duration
+        f_val = self.f
+        fmax_val = self.fmax
+        fmode_val = self.fmode
+        fswimode_val = self.fswimode
+        fswi_val = self.fswi
+        fswi_max_val = self.fswi_max
+        typePWM_val = self.typePWM
+        Vdc1_val = self.Vdc1
+        U0_val = self.U0
+        type_carrier_val = self.type_carrier
+        var_amp_val = self.var_amp
+        qs_val = self.qs
+        is_star_val = self.is_star
+        phase_dir_val = self.phase_dir
+        current_dir_val = self.current_dir
+        Phi0_val = self.Phi0
+        is_transpose_val = self.is_transpose
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            fs=fs_val,
+            duration=duration_val,
+            f=f_val,
+            fmax=fmax_val,
+            fmode=fmode_val,
+            fswimode=fswimode_val,
+            fswi=fswi_val,
+            fswi_max=fswi_max_val,
+            typePWM=typePWM_val,
+            Vdc1=Vdc1_val,
+            U0=U0_val,
+            type_carrier=type_carrier_val,
+            var_amp=var_amp_val,
+            qs=qs_val,
+            is_star=is_star_val,
+            phase_dir=phase_dir_val,
+            current_dir=current_dir_val,
+            Phi0=Phi0_val,
+            is_transpose=is_transpose_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -334,7 +656,9 @@ class ImportGenPWM(ImportMatrix):
         self.var_amp = None
         self.qs = None
         self.is_star = None
-        self.rot_dir = None
+        self.phase_dir = None
+        self.current_dir = None
+        self.Phi0 = None
         # Set to None the properties inherited from ImportMatrix
         super(ImportGenPWM, self)._set_None()
 
@@ -535,7 +859,7 @@ class ImportGenPWM(ImportMatrix):
     U0 = property(
         fget=_get_U0,
         fset=_set_U0,
-        doc=u"""reference voltage
+        doc=u"""reference voltage amplitude (rms)
 
         :Type: float
         """,
@@ -613,20 +937,60 @@ class ImportGenPWM(ImportMatrix):
         """,
     )
 
-    def _get_rot_dir(self):
-        """getter of rot_dir"""
-        return self._rot_dir
+    def _get_phase_dir(self):
+        """getter of phase_dir"""
+        return self._phase_dir
 
-    def _set_rot_dir(self, value):
-        """setter of rot_dir"""
-        check_var("rot_dir", value, "int")
-        self._rot_dir = value
+    def _set_phase_dir(self, value):
+        """setter of phase_dir"""
+        check_var("phase_dir", value, "int", Vmin=-1, Vmax=1)
+        self._phase_dir = value
 
-    rot_dir = property(
-        fget=_get_rot_dir,
-        fset=_set_rot_dir,
-        doc=u"""rotor rotation direction
+    phase_dir = property(
+        fget=_get_phase_dir,
+        fset=_set_phase_dir,
+        doc=u"""Rotation direction of the stator phases (phase_dir*(n-1)*pi/qs, default value given by PHASE_DIR_REF)
 
         :Type: int
+        :min: -1
+        :max: 1
+        """,
+    )
+
+    def _get_current_dir(self):
+        """getter of current_dir"""
+        return self._current_dir
+
+    def _set_current_dir(self, value):
+        """setter of current_dir"""
+        check_var("current_dir", value, "int", Vmin=-1, Vmax=1)
+        self._current_dir = value
+
+    current_dir = property(
+        fget=_get_current_dir,
+        fset=_set_current_dir,
+        doc=u"""Rotation direction of the stator currents (current_dir*2*pi*felec*time, default value given by CURRENT_DIR_REF)
+
+        :Type: int
+        :min: -1
+        :max: 1
+        """,
+    )
+
+    def _get_Phi0(self):
+        """getter of Phi0"""
+        return self._Phi0
+
+    def _set_Phi0(self, value):
+        """setter of Phi0"""
+        check_var("Phi0", value, "float")
+        self._Phi0 = value
+
+    Phi0 = property(
+        fget=_get_Phi0,
+        fset=_set_Phi0,
+        doc=u"""reference voltage phase (rad)
+
+        :Type: float
         """,
     )
