@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Input import Input
 
 # Import all class method
@@ -23,18 +23,16 @@ except ImportError as error:
     gen_input = error
 
 try:
-    from ..Methods.Simulation.InputVoltage.set_OP_from_array import set_OP_from_array
+    from ..Methods.Simulation.InputVoltage.set_Ud_Uq import set_Ud_Uq
 except ImportError as error:
-    set_OP_from_array = error
+    set_Ud_Uq = error
 
 
 from ..Classes.ImportMatrixVal import ImportMatrixVal
 from numpy import ndarray
 from numpy import array, array_equal
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .ImportGenPWM import ImportGenPWM
-from .ImportMatrix import ImportMatrix
-from .OP import OP
 
 
 class InputVoltage(Input):
@@ -54,21 +52,19 @@ class InputVoltage(Input):
         )
     else:
         gen_input = gen_input
-    # cf Methods.Simulation.InputVoltage.set_OP_from_array
-    if isinstance(set_OP_from_array, ImportError):
-        set_OP_from_array = property(
+    # cf Methods.Simulation.InputVoltage.set_Ud_Uq
+    if isinstance(set_Ud_Uq, ImportError):
+        set_Ud_Uq = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use InputVoltage method set_OP_from_array: "
-                    + str(set_OP_from_array)
+                    "Can't use InputVoltage method set_Ud_Uq: " + str(set_Ud_Uq)
                 )
             )
         )
     else:
-        set_OP_from_array = set_OP_from_array
-    # save and copy methods are available in all object
+        set_Ud_Uq = set_Ud_Uq
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -79,12 +75,16 @@ class InputVoltage(Input):
         PWM=None,
         phase_dir=None,
         current_dir=None,
+        is_periodicity_t=False,
+        is_periodicity_a=False,
+        is_generator=False,
         time=None,
         angle=None,
         Nt_tot=2048,
         Nrev=None,
         Na_tot=2048,
         OP=None,
+        t_final=None,
         init_dict=None,
         init_str=None,
     ):
@@ -113,6 +113,12 @@ class InputVoltage(Input):
                 phase_dir = init_dict["phase_dir"]
             if "current_dir" in list(init_dict.keys()):
                 current_dir = init_dict["current_dir"]
+            if "is_periodicity_t" in list(init_dict.keys()):
+                is_periodicity_t = init_dict["is_periodicity_t"]
+            if "is_periodicity_a" in list(init_dict.keys()):
+                is_periodicity_a = init_dict["is_periodicity_a"]
+            if "is_generator" in list(init_dict.keys()):
+                is_generator = init_dict["is_generator"]
             if "time" in list(init_dict.keys()):
                 time = init_dict["time"]
             if "angle" in list(init_dict.keys()):
@@ -125,15 +131,26 @@ class InputVoltage(Input):
                 Na_tot = init_dict["Na_tot"]
             if "OP" in list(init_dict.keys()):
                 OP = init_dict["OP"]
+            if "t_final" in list(init_dict.keys()):
+                t_final = init_dict["t_final"]
         # Set the properties (value check and convertion are done in setter)
         self.rot_dir = rot_dir
         self.angle_rotor_initial = angle_rotor_initial
         self.PWM = PWM
         self.phase_dir = phase_dir
         self.current_dir = current_dir
+        self.is_periodicity_t = is_periodicity_t
+        self.is_periodicity_a = is_periodicity_a
+        self.is_generator = is_generator
         # Call Input init
         super(InputVoltage, self).__init__(
-            time=time, angle=angle, Nt_tot=Nt_tot, Nrev=Nrev, Na_tot=Na_tot, OP=OP
+            time=time,
+            angle=angle,
+            Nt_tot=Nt_tot,
+            Nrev=Nrev,
+            Na_tot=Na_tot,
+            OP=OP,
+            t_final=t_final,
         )
         # The class is frozen (in Input init), for now it's impossible to
         # add new properties
@@ -155,6 +172,9 @@ class InputVoltage(Input):
             InputVoltage_str += "PWM = None" + linesep + linesep
         InputVoltage_str += "phase_dir = " + str(self.phase_dir) + linesep
         InputVoltage_str += "current_dir = " + str(self.current_dir) + linesep
+        InputVoltage_str += "is_periodicity_t = " + str(self.is_periodicity_t) + linesep
+        InputVoltage_str += "is_periodicity_a = " + str(self.is_periodicity_a) + linesep
+        InputVoltage_str += "is_generator = " + str(self.is_generator) + linesep
         return InputVoltage_str
 
     def __eq__(self, other):
@@ -176,9 +196,15 @@ class InputVoltage(Input):
             return False
         if other.current_dir != self.current_dir:
             return False
+        if other.is_periodicity_t != self.is_periodicity_t:
+            return False
+        if other.is_periodicity_a != self.is_periodicity_a:
+            return False
+        if other.is_generator != self.is_generator:
+            return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -188,21 +214,115 @@ class InputVoltage(Input):
         diff_list = list()
 
         # Check the properties inherited from Input
-        diff_list.extend(super(InputVoltage, self).compare(other, name=name))
+        diff_list.extend(
+            super(InputVoltage, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._rot_dir != self._rot_dir:
-            diff_list.append(name + ".rot_dir")
-        if other._angle_rotor_initial != self._angle_rotor_initial:
-            diff_list.append(name + ".angle_rotor_initial")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._rot_dir)
+                    + ", other="
+                    + str(other._rot_dir)
+                    + ")"
+                )
+                diff_list.append(name + ".rot_dir" + val_str)
+            else:
+                diff_list.append(name + ".rot_dir")
+        if (
+            other._angle_rotor_initial is not None
+            and self._angle_rotor_initial is not None
+            and isnan(other._angle_rotor_initial)
+            and isnan(self._angle_rotor_initial)
+        ):
+            pass
+        elif other._angle_rotor_initial != self._angle_rotor_initial:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._angle_rotor_initial)
+                    + ", other="
+                    + str(other._angle_rotor_initial)
+                    + ")"
+                )
+                diff_list.append(name + ".angle_rotor_initial" + val_str)
+            else:
+                diff_list.append(name + ".angle_rotor_initial")
         if (other.PWM is None and self.PWM is not None) or (
             other.PWM is not None and self.PWM is None
         ):
             diff_list.append(name + ".PWM None mismatch")
         elif self.PWM is not None:
-            diff_list.extend(self.PWM.compare(other.PWM, name=name + ".PWM"))
+            diff_list.extend(
+                self.PWM.compare(
+                    other.PWM,
+                    name=name + ".PWM",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         if other._phase_dir != self._phase_dir:
-            diff_list.append(name + ".phase_dir")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._phase_dir)
+                    + ", other="
+                    + str(other._phase_dir)
+                    + ")"
+                )
+                diff_list.append(name + ".phase_dir" + val_str)
+            else:
+                diff_list.append(name + ".phase_dir")
         if other._current_dir != self._current_dir:
-            diff_list.append(name + ".current_dir")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._current_dir)
+                    + ", other="
+                    + str(other._current_dir)
+                    + ")"
+                )
+                diff_list.append(name + ".current_dir" + val_str)
+            else:
+                diff_list.append(name + ".current_dir")
+        if other._is_periodicity_t != self._is_periodicity_t:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_periodicity_t)
+                    + ", other="
+                    + str(other._is_periodicity_t)
+                    + ")"
+                )
+                diff_list.append(name + ".is_periodicity_t" + val_str)
+            else:
+                diff_list.append(name + ".is_periodicity_t")
+        if other._is_periodicity_a != self._is_periodicity_a:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_periodicity_a)
+                    + ", other="
+                    + str(other._is_periodicity_a)
+                    + ")"
+                )
+                diff_list.append(name + ".is_periodicity_a" + val_str)
+            else:
+                diff_list.append(name + ".is_periodicity_a")
+        if other._is_generator != self._is_generator:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._is_generator)
+                    + ", other="
+                    + str(other._is_generator)
+                    + ")"
+                )
+                diff_list.append(name + ".is_generator" + val_str)
+            else:
+                diff_list.append(name + ".is_generator")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -219,6 +339,9 @@ class InputVoltage(Input):
         S += getsizeof(self.PWM)
         S += getsizeof(self.phase_dir)
         S += getsizeof(self.current_dir)
+        S += getsizeof(self.is_periodicity_t)
+        S += getsizeof(self.is_periodicity_a)
+        S += getsizeof(self.is_generator)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -250,11 +373,65 @@ class InputVoltage(Input):
             )
         InputVoltage_dict["phase_dir"] = self.phase_dir
         InputVoltage_dict["current_dir"] = self.current_dir
+        InputVoltage_dict["is_periodicity_t"] = self.is_periodicity_t
+        InputVoltage_dict["is_periodicity_a"] = self.is_periodicity_a
+        InputVoltage_dict["is_generator"] = self.is_generator
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         InputVoltage_dict["__class__"] = "InputVoltage"
         return InputVoltage_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        rot_dir_val = self.rot_dir
+        angle_rotor_initial_val = self.angle_rotor_initial
+        if self.PWM is None:
+            PWM_val = None
+        else:
+            PWM_val = self.PWM.copy()
+        phase_dir_val = self.phase_dir
+        current_dir_val = self.current_dir
+        is_periodicity_t_val = self.is_periodicity_t
+        is_periodicity_a_val = self.is_periodicity_a
+        is_generator_val = self.is_generator
+        if self.time is None:
+            time_val = None
+        else:
+            time_val = self.time.copy()
+        if self.angle is None:
+            angle_val = None
+        else:
+            angle_val = self.angle.copy()
+        Nt_tot_val = self.Nt_tot
+        Nrev_val = self.Nrev
+        Na_tot_val = self.Na_tot
+        if self.OP is None:
+            OP_val = None
+        else:
+            OP_val = self.OP.copy()
+        t_final_val = self.t_final
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            rot_dir=rot_dir_val,
+            angle_rotor_initial=angle_rotor_initial_val,
+            PWM=PWM_val,
+            phase_dir=phase_dir_val,
+            current_dir=current_dir_val,
+            is_periodicity_t=is_periodicity_t_val,
+            is_periodicity_a=is_periodicity_a_val,
+            is_generator=is_generator_val,
+            time=time_val,
+            angle=angle_val,
+            Nt_tot=Nt_tot_val,
+            Nrev=Nrev_val,
+            Na_tot=Na_tot_val,
+            OP=OP_val,
+            t_final=t_final_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -264,6 +441,9 @@ class InputVoltage(Input):
             self.PWM._set_None()
         self.phase_dir = None
         self.current_dir = None
+        self.is_periodicity_t = None
+        self.is_periodicity_a = None
+        self.is_generator = None
         # Set to None the properties inherited from Input
         super(InputVoltage, self)._set_None()
 
@@ -312,11 +492,18 @@ class InputVoltage(Input):
     def _set_PWM(self, value):
         """setter of PWM"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class("pyleecan.Classes", value.get("__class__"), "PWM")
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            ImportGenPWM = import_class("pyleecan.Classes", "ImportGenPWM", "PWM")
             value = ImportGenPWM()
         check_var("PWM", value, "ImportGenPWM")
         self._PWM = value
@@ -372,3 +559,57 @@ class InputVoltage(Input):
         :max: 1
         """,
     )
+
+    def _get_is_periodicity_t(self):
+        """getter of is_periodicity_t"""
+        return self._is_periodicity_t
+
+    def _set_is_periodicity_t(self, value):
+        """setter of is_periodicity_t"""
+        check_var("is_periodicity_t", value, "bool")
+        self._is_periodicity_t = value
+
+    is_periodicity_t = property(
+        fget=_get_is_periodicity_t,
+        fset=_set_is_periodicity_t,
+        doc=u"""True to compute voltage/currents only on one time periodicity (use periodicities defined in axes_dict[time])
+
+        :Type: bool
+        """,
+    )
+
+    def _get_is_periodicity_a(self):
+        """getter of is_periodicity_a"""
+        return self._is_periodicity_a
+
+    def _set_is_periodicity_a(self, value):
+        """setter of is_periodicity_a"""
+        check_var("is_periodicity_a", value, "bool")
+        self._is_periodicity_a = value
+
+    is_periodicity_a = property(
+        fget=_get_is_periodicity_a,
+        fset=_set_is_periodicity_a,
+        doc=u"""True to compute voltage/currents only on one angle periodicity (use periodicities defined in axes_dict[angle])
+
+        :Type: bool
+        """,
+    )
+
+    def _get_is_generator(self):
+        """getter of is_generator"""
+        return self._is_generator
+
+    def _set_is_generator(self, value):
+        """setter of is_generator"""
+        check_var("is_generator", value, "bool")
+        self._is_generator = value
+
+    is_generator = property(
+        fget=_get_is_generator,
+        fset=_set_is_generator,
+        doc=u"""True if machine is used as a generator
+
+        :Type: bool
+        """,
+    )
