@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .LamSquirrelCage import LamSquirrelCage
 
 # Import all class method
@@ -51,15 +51,14 @@ try:
 except ImportError as error:
     set_pole_pair_number = error
 
+try:
+    from ..Methods.Machine.LamSquirrelCageMag.get_hole_list import get_hole_list
+except ImportError as error:
+    get_hole_list = error
 
+
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Hole import Hole
-from .Material import Material
-from .Winding import Winding
-from .Slot import Slot
-from .Notch import Notch
-from .Skew import Skew
-from .Bore import Bore
 
 
 class LamSquirrelCageMag(LamSquirrelCage):
@@ -134,9 +133,20 @@ class LamSquirrelCageMag(LamSquirrelCage):
         )
     else:
         set_pole_pair_number = set_pole_pair_number
-    # save and copy methods are available in all object
+    # cf Methods.Machine.LamSquirrelCageMag.get_hole_list
+    if isinstance(get_hole_list, ImportError):
+        get_hole_list = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use LamSquirrelCageMag method get_hole_list: "
+                    + str(get_hole_list)
+                )
+            )
+        )
+    else:
+        get_hole_list = get_hole_list
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -161,8 +171,8 @@ class LamSquirrelCageMag(LamSquirrelCage):
         axial_vent=-1,
         notch=-1,
         skew=None,
-        yoke_notch=-1,
         bore=None,
+        yoke=None,
         init_dict=None,
         init_str=None,
     ):
@@ -219,10 +229,10 @@ class LamSquirrelCageMag(LamSquirrelCage):
                 notch = init_dict["notch"]
             if "skew" in list(init_dict.keys()):
                 skew = init_dict["skew"]
-            if "yoke_notch" in list(init_dict.keys()):
-                yoke_notch = init_dict["yoke_notch"]
             if "bore" in list(init_dict.keys()):
                 bore = init_dict["bore"]
+            if "yoke" in list(init_dict.keys()):
+                yoke = init_dict["yoke"]
         # Set the properties (value check and convertion are done in setter)
         self.hole = hole
         # Call LamSquirrelCage init
@@ -245,8 +255,8 @@ class LamSquirrelCageMag(LamSquirrelCage):
             axial_vent=axial_vent,
             notch=notch,
             skew=skew,
-            yoke_notch=yoke_notch,
             bore=bore,
+            yoke=yoke,
         )
         # The class is frozen (in LamSquirrelCage init), for now it's impossible to
         # add new properties
@@ -279,7 +289,7 @@ class LamSquirrelCageMag(LamSquirrelCage):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -289,7 +299,11 @@ class LamSquirrelCageMag(LamSquirrelCage):
         diff_list = list()
 
         # Check the properties inherited from LamSquirrelCage
-        diff_list.extend(super(LamSquirrelCageMag, self).compare(other, name=name))
+        diff_list.extend(
+            super(LamSquirrelCageMag, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if (other.hole is None and self.hole is not None) or (
             other.hole is not None and self.hole is None
         ):
@@ -302,7 +316,10 @@ class LamSquirrelCageMag(LamSquirrelCage):
             for ii in range(len(other.hole)):
                 diff_list.extend(
                     self.hole[ii].compare(
-                        other.hole[ii], name=name + ".hole[" + str(ii) + "]"
+                        other.hole[ii],
+                        name=name + ".hole[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         # Filter ignore differences
@@ -358,6 +375,93 @@ class LamSquirrelCageMag(LamSquirrelCage):
         LamSquirrelCageMag_dict["__class__"] = "LamSquirrelCageMag"
         return LamSquirrelCageMag_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.hole is None:
+            hole_val = None
+        else:
+            hole_val = list()
+            for obj in self.hole:
+                hole_val.append(obj.copy())
+        Hscr_val = self.Hscr
+        Lscr_val = self.Lscr
+        if self.ring_mat is None:
+            ring_mat_val = None
+        else:
+            ring_mat_val = self.ring_mat.copy()
+        Ksfill_val = self.Ksfill
+        if self.winding is None:
+            winding_val = None
+        else:
+            winding_val = self.winding.copy()
+        if self.slot is None:
+            slot_val = None
+        else:
+            slot_val = self.slot.copy()
+        L1_val = self.L1
+        if self.mat_type is None:
+            mat_type_val = None
+        else:
+            mat_type_val = self.mat_type.copy()
+        Nrvd_val = self.Nrvd
+        Wrvd_val = self.Wrvd
+        Kf1_val = self.Kf1
+        is_internal_val = self.is_internal
+        Rint_val = self.Rint
+        Rext_val = self.Rext
+        is_stator_val = self.is_stator
+        if self.axial_vent is None:
+            axial_vent_val = None
+        else:
+            axial_vent_val = list()
+            for obj in self.axial_vent:
+                axial_vent_val.append(obj.copy())
+        if self.notch is None:
+            notch_val = None
+        else:
+            notch_val = list()
+            for obj in self.notch:
+                notch_val.append(obj.copy())
+        if self.skew is None:
+            skew_val = None
+        else:
+            skew_val = self.skew.copy()
+        if self.bore is None:
+            bore_val = None
+        else:
+            bore_val = self.bore.copy()
+        if self.yoke is None:
+            yoke_val = None
+        else:
+            yoke_val = self.yoke.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            hole=hole_val,
+            Hscr=Hscr_val,
+            Lscr=Lscr_val,
+            ring_mat=ring_mat_val,
+            Ksfill=Ksfill_val,
+            winding=winding_val,
+            slot=slot_val,
+            L1=L1_val,
+            mat_type=mat_type_val,
+            Nrvd=Nrvd_val,
+            Wrvd=Wrvd_val,
+            Kf1=Kf1_val,
+            is_internal=is_internal_val,
+            Rint=Rint_val,
+            Rext=Rext_val,
+            is_stator=is_stator_val,
+            axial_vent=axial_vent_val,
+            notch=notch_val,
+            skew=skew_val,
+            bore=bore_val,
+            yoke=yoke_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -377,6 +481,15 @@ class LamSquirrelCageMag(LamSquirrelCage):
         """setter of hole"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "hole"
