@@ -10,11 +10,25 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
+# Import all class method
+# Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Material.MatElectrical.get_conductivity import get_conductivity
+except ImportError as error:
+    get_conductivity = error
+
+try:
+    from ..Methods.Material.MatElectrical.get_resistivity import get_resistivity
+except ImportError as error:
+    get_resistivity = error
+
+
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -23,13 +37,37 @@ class MatElectrical(FrozenClass):
 
     VERSION = 1
 
-    # save and copy methods are available in all object
+    # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.Material.MatElectrical.get_conductivity
+    if isinstance(get_conductivity, ImportError):
+        get_conductivity = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use MatElectrical method get_conductivity: "
+                    + str(get_conductivity)
+                )
+            )
+        )
+    else:
+        get_conductivity = get_conductivity
+    # cf Methods.Material.MatElectrical.get_resistivity
+    if isinstance(get_resistivity, ImportError):
+        get_resistivity = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use MatElectrical method get_resistivity: "
+                    + str(get_resistivity)
+                )
+            )
+        )
+    else:
+        get_resistivity = get_resistivity
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
-    def __init__(self, rho=1, epsr=1, alpha=1, init_dict=None, init_str=None):
+    def __init__(self, rho=0, epsr=1, alpha=0, init_dict=None, init_str=None):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
@@ -88,7 +126,7 @@ class MatElectrical(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -96,12 +134,51 @@ class MatElectrical(FrozenClass):
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
-        if other._rho != self._rho:
-            diff_list.append(name + ".rho")
-        if other._epsr != self._epsr:
-            diff_list.append(name + ".epsr")
-        if other._alpha != self._alpha:
-            diff_list.append(name + ".alpha")
+        if (
+            other._rho is not None
+            and self._rho is not None
+            and isnan(other._rho)
+            and isnan(self._rho)
+        ):
+            pass
+        elif other._rho != self._rho:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._rho) + ", other=" + str(other._rho) + ")"
+                )
+                diff_list.append(name + ".rho" + val_str)
+            else:
+                diff_list.append(name + ".rho")
+        if (
+            other._epsr is not None
+            and self._epsr is not None
+            and isnan(other._epsr)
+            and isnan(self._epsr)
+        ):
+            pass
+        elif other._epsr != self._epsr:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._epsr) + ", other=" + str(other._epsr) + ")"
+                )
+                diff_list.append(name + ".epsr" + val_str)
+            else:
+                diff_list.append(name + ".epsr")
+        if (
+            other._alpha is not None
+            and self._alpha is not None
+            and isnan(other._alpha)
+            and isnan(self._alpha)
+        ):
+            pass
+        elif other._alpha != self._alpha:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._alpha) + ", other=" + str(other._alpha) + ")"
+                )
+                diff_list.append(name + ".alpha" + val_str)
+            else:
+                diff_list.append(name + ".alpha")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -134,6 +211,17 @@ class MatElectrical(FrozenClass):
         MatElectrical_dict["__class__"] = "MatElectrical"
         return MatElectrical_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        rho_val = self.rho
+        epsr_val = self.epsr
+        alpha_val = self.alpha
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(rho=rho_val, epsr=epsr_val, alpha=alpha_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -191,7 +279,7 @@ class MatElectrical(FrozenClass):
     alpha = property(
         fget=_get_alpha,
         fset=_set_alpha,
-        doc=u"""Thermal Coefficient
+        doc=u"""Thermal resistivity coefficient
 
         :Type: float
         :min: 0
