@@ -18,9 +18,9 @@ from .Mesh import Mesh
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
 try:
-    from ..Methods.Mesh.MeshMat.get_node import get_node
+    from ..Methods.Mesh.MeshMat.get_node_coordinate import get_node_coordinate
 except ImportError as error:
-    get_node = error
+    get_node_coordinate = error
 
 try:
     from ..Methods.Mesh.MeshMat.get_node_indice import get_node_indice
@@ -28,9 +28,9 @@ except ImportError as error:
     get_node_indice = error
 
 try:
-    from ..Methods.Mesh.MeshMat.get_cell import get_cell
+    from ..Methods.Mesh.MeshMat.get_element import get_element
 except ImportError as error:
-    get_cell = error
+    get_element = error
 
 try:
     from ..Methods.Mesh.MeshMat.get_mesh_pv import get_mesh_pv
@@ -38,24 +38,24 @@ except ImportError as error:
     get_mesh_pv = error
 
 try:
-    from ..Methods.Mesh.MeshMat.get_cell_area import get_cell_area
+    from ..Methods.Mesh.MeshMat.get_element_area import get_element_area
 except ImportError as error:
-    get_cell_area = error
+    get_element_area = error
 
 try:
-    from ..Methods.Mesh.MeshMat.get_vertice import get_vertice
+    from ..Methods.Mesh.MeshMat.get_element_coordinate import get_element_coordinate
 except ImportError as error:
-    get_vertice = error
+    get_element_coordinate = error
 
 try:
-    from ..Methods.Mesh.MeshMat.get_node2cell import get_node2cell
+    from ..Methods.Mesh.MeshMat.get_node2element import get_node2element
 except ImportError as error:
-    get_node2cell = error
+    get_node2element = error
 
 try:
-    from ..Methods.Mesh.MeshMat.add_cell import add_cell
+    from ..Methods.Mesh.MeshMat.add_element import add_element
 except ImportError as error:
-    add_cell = error
+    add_element = error
 
 try:
     from ..Methods.Mesh.MeshMat.renum import renum
@@ -63,9 +63,9 @@ except ImportError as error:
     renum = error
 
 try:
-    from ..Methods.Mesh.MeshMat.find_cell import find_cell
+    from ..Methods.Mesh.MeshMat.find_element import find_element
 except ImportError as error:
-    find_cell = error
+    find_element = error
 
 try:
     from ..Methods.Mesh.MeshMat.interface import interface
@@ -78,9 +78,24 @@ except ImportError as error:
     clear_node = error
 
 try:
-    from ..Methods.Mesh.MeshMat.clear_cell import clear_cell
+    from ..Methods.Mesh.MeshMat.clear_element import clear_element
 except ImportError as error:
-    clear_cell = error
+    clear_element = error
+
+try:
+    from ..Methods.Mesh.MeshMat.get_element_nb import get_element_nb
+except ImportError as error:
+    get_element_nb = error
+
+try:
+    from ..Methods.Mesh.MeshMat.convert import convert
+except ImportError as error:
+    convert = error
+
+try:
+    from ..Methods.Mesh.MeshMat.save_vtk import save_vtk
+except ImportError as error:
+    save_vtk = error
 
 
 from numpy import isnan
@@ -93,15 +108,18 @@ class MeshMat(Mesh):
     VERSION = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
-    # cf Methods.Mesh.MeshMat.get_node
-    if isinstance(get_node, ImportError):
-        get_node = property(
+    # cf Methods.Mesh.MeshMat.get_node_coordinate
+    if isinstance(get_node_coordinate, ImportError):
+        get_node_coordinate = property(
             fget=lambda x: raise_(
-                ImportError("Can't use MeshMat method get_node: " + str(get_node))
+                ImportError(
+                    "Can't use MeshMat method get_node_coordinate: "
+                    + str(get_node_coordinate)
+                )
             )
         )
     else:
-        get_node = get_node
+        get_node_coordinate = get_node_coordinate
     # cf Methods.Mesh.MeshMat.get_node_indice
     if isinstance(get_node_indice, ImportError):
         get_node_indice = property(
@@ -113,15 +131,15 @@ class MeshMat(Mesh):
         )
     else:
         get_node_indice = get_node_indice
-    # cf Methods.Mesh.MeshMat.get_cell
-    if isinstance(get_cell, ImportError):
-        get_cell = property(
+    # cf Methods.Mesh.MeshMat.get_element
+    if isinstance(get_element, ImportError):
+        get_element = property(
             fget=lambda x: raise_(
-                ImportError("Can't use MeshMat method get_cell: " + str(get_cell))
+                ImportError("Can't use MeshMat method get_element: " + str(get_element))
             )
         )
     else:
-        get_cell = get_cell
+        get_element = get_element
     # cf Methods.Mesh.MeshMat.get_mesh_pv
     if isinstance(get_mesh_pv, ImportError):
         get_mesh_pv = property(
@@ -131,46 +149,51 @@ class MeshMat(Mesh):
         )
     else:
         get_mesh_pv = get_mesh_pv
-    # cf Methods.Mesh.MeshMat.get_cell_area
-    if isinstance(get_cell_area, ImportError):
-        get_cell_area = property(
+    # cf Methods.Mesh.MeshMat.get_element_area
+    if isinstance(get_element_area, ImportError):
+        get_element_area = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use MeshMat method get_cell_area: " + str(get_cell_area)
+                    "Can't use MeshMat method get_element_area: "
+                    + str(get_element_area)
                 )
             )
         )
     else:
-        get_cell_area = get_cell_area
-    # cf Methods.Mesh.MeshMat.get_vertice
-    if isinstance(get_vertice, ImportError):
-        get_vertice = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use MeshMat method get_vertice: " + str(get_vertice))
-            )
-        )
-    else:
-        get_vertice = get_vertice
-    # cf Methods.Mesh.MeshMat.get_node2cell
-    if isinstance(get_node2cell, ImportError):
-        get_node2cell = property(
+        get_element_area = get_element_area
+    # cf Methods.Mesh.MeshMat.get_element_coordinate
+    if isinstance(get_element_coordinate, ImportError):
+        get_element_coordinate = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use MeshMat method get_node2cell: " + str(get_node2cell)
+                    "Can't use MeshMat method get_element_coordinate: "
+                    + str(get_element_coordinate)
                 )
             )
         )
     else:
-        get_node2cell = get_node2cell
-    # cf Methods.Mesh.MeshMat.add_cell
-    if isinstance(add_cell, ImportError):
-        add_cell = property(
+        get_element_coordinate = get_element_coordinate
+    # cf Methods.Mesh.MeshMat.get_node2element
+    if isinstance(get_node2element, ImportError):
+        get_node2element = property(
             fget=lambda x: raise_(
-                ImportError("Can't use MeshMat method add_cell: " + str(add_cell))
+                ImportError(
+                    "Can't use MeshMat method get_node2element: "
+                    + str(get_node2element)
+                )
             )
         )
     else:
-        add_cell = add_cell
+        get_node2element = get_node2element
+    # cf Methods.Mesh.MeshMat.add_element
+    if isinstance(add_element, ImportError):
+        add_element = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use MeshMat method add_element: " + str(add_element))
+            )
+        )
+    else:
+        add_element = add_element
     # cf Methods.Mesh.MeshMat.renum
     if isinstance(renum, ImportError):
         renum = property(
@@ -180,15 +203,17 @@ class MeshMat(Mesh):
         )
     else:
         renum = renum
-    # cf Methods.Mesh.MeshMat.find_cell
-    if isinstance(find_cell, ImportError):
-        find_cell = property(
+    # cf Methods.Mesh.MeshMat.find_element
+    if isinstance(find_element, ImportError):
+        find_element = property(
             fget=lambda x: raise_(
-                ImportError("Can't use MeshMat method find_cell: " + str(find_cell))
+                ImportError(
+                    "Can't use MeshMat method find_element: " + str(find_element)
+                )
             )
         )
     else:
-        find_cell = find_cell
+        find_element = find_element
     # cf Methods.Mesh.MeshMat.interface
     if isinstance(interface, ImportError):
         interface = property(
@@ -207,15 +232,46 @@ class MeshMat(Mesh):
         )
     else:
         clear_node = clear_node
-    # cf Methods.Mesh.MeshMat.clear_cell
-    if isinstance(clear_cell, ImportError):
-        clear_cell = property(
+    # cf Methods.Mesh.MeshMat.clear_element
+    if isinstance(clear_element, ImportError):
+        clear_element = property(
             fget=lambda x: raise_(
-                ImportError("Can't use MeshMat method clear_cell: " + str(clear_cell))
+                ImportError(
+                    "Can't use MeshMat method clear_element: " + str(clear_element)
+                )
             )
         )
     else:
-        clear_cell = clear_cell
+        clear_element = clear_element
+    # cf Methods.Mesh.MeshMat.get_element_nb
+    if isinstance(get_element_nb, ImportError):
+        get_element_nb = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use MeshMat method get_element_nb: " + str(get_element_nb)
+                )
+            )
+        )
+    else:
+        get_element_nb = get_element_nb
+    # cf Methods.Mesh.MeshMat.convert
+    if isinstance(convert, ImportError):
+        convert = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use MeshMat method convert: " + str(convert))
+            )
+        )
+    else:
+        convert = convert
+    # cf Methods.Mesh.MeshMat.save_vtk
+    if isinstance(save_vtk, ImportError):
+        save_vtk = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use MeshMat method save_vtk: " + str(save_vtk))
+            )
+        )
+    else:
+        save_vtk = save_vtk
     # generic save method is available in all object
     save = save
     # get_logger method is available in all object
@@ -223,12 +279,11 @@ class MeshMat(Mesh):
 
     def __init__(
         self,
-        cell=-1,
+        element_dict=-1,
         node=-1,
         _is_renum=False,
         sym=1,
         is_antiper_a=False,
-        label=None,
         dimension=2,
         init_dict=None,
         init_str=None,
@@ -248,8 +303,8 @@ class MeshMat(Mesh):
         if init_dict is not None:  # Initialisation by dict
             assert type(init_dict) is dict
             # Overwrite default value with init_dict content
-            if "cell" in list(init_dict.keys()):
-                cell = init_dict["cell"]
+            if "element_dict" in list(init_dict.keys()):
+                element_dict = init_dict["element_dict"]
             if "node" in list(init_dict.keys()):
                 node = init_dict["node"]
             if "_is_renum" in list(init_dict.keys()):
@@ -258,18 +313,16 @@ class MeshMat(Mesh):
                 sym = init_dict["sym"]
             if "is_antiper_a" in list(init_dict.keys()):
                 is_antiper_a = init_dict["is_antiper_a"]
-            if "label" in list(init_dict.keys()):
-                label = init_dict["label"]
             if "dimension" in list(init_dict.keys()):
                 dimension = init_dict["dimension"]
         # Set the properties (value check and convertion are done in setter)
-        self.cell = cell
+        self.element_dict = element_dict
         self.node = node
         self._is_renum = _is_renum
         self.sym = sym
         self.is_antiper_a = is_antiper_a
         # Call Mesh init
-        super(MeshMat, self).__init__(label=label, dimension=dimension)
+        super(MeshMat, self).__init__(dimension=dimension)
         # The class is frozen (in Mesh init), for now it's impossible to
         # add new properties
 
@@ -279,11 +332,14 @@ class MeshMat(Mesh):
         MeshMat_str = ""
         # Get the properties inherited from Mesh
         MeshMat_str += super(MeshMat, self).__str__()
-        if len(self.cell) == 0:
-            MeshMat_str += "cell = dict()" + linesep
-        for key, obj in self.cell.items():
-            tmp = self.cell[key].__str__().replace(linesep, linesep + "\t") + linesep
-            MeshMat_str += "cell[" + key + "] =" + tmp + linesep + linesep
+        if len(self.element_dict) == 0:
+            MeshMat_str += "element_dict = dict()" + linesep
+        for key, obj in self.element_dict.items():
+            tmp = (
+                self.element_dict[key].__str__().replace(linesep, linesep + "\t")
+                + linesep
+            )
+            MeshMat_str += "element_dict[" + key + "] =" + tmp + linesep + linesep
         if self.node is not None:
             tmp = self.node.__str__().replace(linesep, linesep + "\t").rstrip("\t")
             MeshMat_str += "node = " + tmp
@@ -303,7 +359,7 @@ class MeshMat(Mesh):
         # Check the properties inherited from Mesh
         if not super(MeshMat, self).__eq__(other):
             return False
-        if other.cell != self.cell:
+        if other.element_dict != self.element_dict:
             return False
         if other.node != self.node:
             return False
@@ -330,20 +386,20 @@ class MeshMat(Mesh):
                 other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
             )
         )
-        if (other.cell is None and self.cell is not None) or (
-            other.cell is not None and self.cell is None
+        if (other.element_dict is None and self.element_dict is not None) or (
+            other.element_dict is not None and self.element_dict is None
         ):
-            diff_list.append(name + ".cell None mismatch")
-        elif self.cell is None:
+            diff_list.append(name + ".element_dict None mismatch")
+        elif self.element_dict is None:
             pass
-        elif len(other.cell) != len(self.cell):
-            diff_list.append("len(" + name + "cell)")
+        elif len(other.element_dict) != len(self.element_dict):
+            diff_list.append("len(" + name + "element_dict)")
         else:
-            for key in self.cell:
+            for key in self.element_dict:
                 diff_list.extend(
-                    self.cell[key].compare(
-                        other.cell[key],
-                        name=name + ".cell[" + str(key) + "]",
+                    self.element_dict[key].compare(
+                        other.element_dict[key],
+                        name=name + ".element_dict[" + str(key) + "]",
                         ignore_list=ignore_list,
                         is_add_value=is_add_value,
                     )
@@ -404,8 +460,8 @@ class MeshMat(Mesh):
 
         # Get size of the properties inherited from Mesh
         S += super(MeshMat, self).__sizeof__()
-        if self.cell is not None:
-            for key, value in self.cell.items():
+        if self.element_dict is not None:
+            for key, value in self.element_dict.items():
                 S += getsizeof(value) + getsizeof(key)
         S += getsizeof(self.node)
         S += getsizeof(self._is_renum)
@@ -430,19 +486,19 @@ class MeshMat(Mesh):
             keep_function=keep_function,
             **kwargs
         )
-        if self.cell is None:
-            MeshMat_dict["cell"] = None
+        if self.element_dict is None:
+            MeshMat_dict["element_dict"] = None
         else:
-            MeshMat_dict["cell"] = dict()
-            for key, obj in self.cell.items():
+            MeshMat_dict["element_dict"] = dict()
+            for key, obj in self.element_dict.items():
                 if obj is not None:
-                    MeshMat_dict["cell"][key] = obj.as_dict(
+                    MeshMat_dict["element_dict"][key] = obj.as_dict(
                         type_handle_ndarray=type_handle_ndarray,
                         keep_function=keep_function,
                         **kwargs
                     )
                 else:
-                    MeshMat_dict["cell"][key] = None
+                    MeshMat_dict["element_dict"][key] = None
         if self.node is None:
             MeshMat_dict["node"] = None
         else:
@@ -463,12 +519,12 @@ class MeshMat(Mesh):
         """Creates a deepcopy of the object"""
 
         # Handle deepcopy of all the properties
-        if self.cell is None:
-            cell_val = None
+        if self.element_dict is None:
+            element_dict_val = None
         else:
-            cell_val = dict()
-            for key, obj in self.cell.items():
-                cell_val[key] = obj.copy()
+            element_dict_val = dict()
+            for key, obj in self.element_dict.items():
+                element_dict_val[key] = obj.copy()
         if self.node is None:
             node_val = None
         else:
@@ -476,16 +532,14 @@ class MeshMat(Mesh):
         _is_renum_val = self._is_renum
         sym_val = self.sym
         is_antiper_a_val = self.is_antiper_a
-        label_val = self.label
         dimension_val = self.dimension
         # Creates new object of the same type with the copied properties
         obj_copy = type(self)(
-            cell=cell_val,
+            element_dict=element_dict_val,
             node=node_val,
             _is_renum=_is_renum_val,
             sym=sym_val,
             is_antiper_a=is_antiper_a_val,
-            label=label_val,
             dimension=dimension_val,
         )
         return obj_copy
@@ -493,7 +547,7 @@ class MeshMat(Mesh):
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
-        self.cell = None
+        self.element_dict = None
         if self.node is not None:
             self.node._set_None()
         self._is_renum = None
@@ -502,16 +556,16 @@ class MeshMat(Mesh):
         # Set to None the properties inherited from Mesh
         super(MeshMat, self)._set_None()
 
-    def _get_cell(self):
-        """getter of cell"""
-        if self._cell is not None:
-            for key, obj in self._cell.items():
+    def _get_element_dict(self):
+        """getter of element_dict"""
+        if self._element_dict is not None:
+            for key, obj in self._element_dict.items():
                 if obj is not None:
                     obj.parent = self
-        return self._cell
+        return self._element_dict
 
-    def _set_cell(self, value):
-        """setter of cell"""
+    def _set_element_dict(self, value):
+        """setter of element_dict"""
         if type(value) is dict:
             for key, obj in value.items():
                 if isinstance(obj, str):  # Load from file
@@ -525,20 +579,20 @@ class MeshMat(Mesh):
                         value[key] = None
                 if type(obj) is dict:
                     class_obj = import_class(
-                        "pyleecan.Classes", obj.get("__class__"), "cell"
+                        "pyleecan.Classes", obj.get("__class__"), "element_dict"
                     )
                     value[key] = class_obj(init_dict=obj)
         if type(value) is int and value == -1:
             value = dict()
-        check_var("cell", value, "{CellMat}")
-        self._cell = value
+        check_var("element_dict", value, "{ElementMat}")
+        self._element_dict = value
 
-    cell = property(
-        fget=_get_cell,
-        fset=_set_cell,
+    element_dict = property(
+        fget=_get_element_dict,
+        fset=_set_element_dict,
         doc=u"""Storing connectivity
 
-        :Type: {CellMat}
+        :Type: {ElementMat}
         """,
     )
 
@@ -589,7 +643,7 @@ class MeshMat(Mesh):
     _is_renum = property(
         fget=_get__is_renum,
         fset=_set__is_renum,
-        doc=u"""True if renumering the nodes and cells is useful when renum method is called (saving calculation time)
+        doc=u"""True if renumering the nodes and elements is useful when renum method is called (saving calculation time)
 
         :Type: bool
         """,
