@@ -23,14 +23,14 @@ except ImportError as error:
     get_mesh_pv = error
 
 try:
-    from ..Methods.Mesh.MeshVTK.get_node import get_node
+    from ..Methods.Mesh.MeshVTK.get_node_coordinate import get_node_coordinate
 except ImportError as error:
-    get_node = error
+    get_node_coordinate = error
 
 try:
-    from ..Methods.Mesh.MeshVTK.get_cell import get_cell
+    from ..Methods.Mesh.MeshVTK.get_element import get_element
 except ImportError as error:
-    get_cell = error
+    get_element = error
 
 try:
     from ..Methods.Mesh.MeshVTK.get_normals import get_normals
@@ -43,9 +43,9 @@ except ImportError as error:
     get_surf = error
 
 try:
-    from ..Methods.Mesh.MeshVTK.get_cell_area import get_cell_area
+    from ..Methods.Mesh.MeshVTK.get_element_area import get_element_area
 except ImportError as error:
-    get_cell_area = error
+    get_element_area = error
 
 try:
     from ..Methods.Mesh.MeshVTK.convert import convert
@@ -62,6 +62,11 @@ try:
 except ImportError as error:
     get_path = error
 
+try:
+    from ..Methods.Mesh.MeshVTK.save_vtk import save_vtk
+except ImportError as error:
+    save_vtk = error
+
 
 from numpy import array, array_equal
 from numpy import isnan
@@ -97,24 +102,27 @@ class MeshVTK(Mesh):
         )
     else:
         get_mesh_pv = get_mesh_pv
-    # cf Methods.Mesh.MeshVTK.get_node
-    if isinstance(get_node, ImportError):
-        get_node = property(
+    # cf Methods.Mesh.MeshVTK.get_node_coordinate
+    if isinstance(get_node_coordinate, ImportError):
+        get_node_coordinate = property(
             fget=lambda x: raise_(
-                ImportError("Can't use MeshVTK method get_node: " + str(get_node))
+                ImportError(
+                    "Can't use MeshVTK method get_node_coordinate: "
+                    + str(get_node_coordinate)
+                )
             )
         )
     else:
-        get_node = get_node
-    # cf Methods.Mesh.MeshVTK.get_cell
-    if isinstance(get_cell, ImportError):
-        get_cell = property(
+        get_node_coordinate = get_node_coordinate
+    # cf Methods.Mesh.MeshVTK.get_element
+    if isinstance(get_element, ImportError):
+        get_element = property(
             fget=lambda x: raise_(
-                ImportError("Can't use MeshVTK method get_cell: " + str(get_cell))
+                ImportError("Can't use MeshVTK method get_element: " + str(get_element))
             )
         )
     else:
-        get_cell = get_cell
+        get_element = get_element
     # cf Methods.Mesh.MeshVTK.get_normals
     if isinstance(get_normals, ImportError):
         get_normals = property(
@@ -133,17 +141,18 @@ class MeshVTK(Mesh):
         )
     else:
         get_surf = get_surf
-    # cf Methods.Mesh.MeshVTK.get_cell_area
-    if isinstance(get_cell_area, ImportError):
-        get_cell_area = property(
+    # cf Methods.Mesh.MeshVTK.get_element_area
+    if isinstance(get_element_area, ImportError):
+        get_element_area = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use MeshVTK method get_cell_area: " + str(get_cell_area)
+                    "Can't use MeshVTK method get_element_area: "
+                    + str(get_element_area)
                 )
             )
         )
     else:
-        get_cell_area = get_cell_area
+        get_element_area = get_element_area
     # cf Methods.Mesh.MeshVTK.convert
     if isinstance(convert, ImportError):
         convert = property(
@@ -171,6 +180,15 @@ class MeshVTK(Mesh):
         )
     else:
         get_path = get_path
+    # cf Methods.Mesh.MeshVTK.save_vtk
+    if isinstance(save_vtk, ImportError):
+        save_vtk = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use MeshVTK method save_vtk: " + str(save_vtk))
+            )
+        )
+    else:
+        save_vtk = save_vtk
     # generic save method is available in all object
     save = save
     # get_logger method is available in all object
@@ -188,7 +206,6 @@ class MeshVTK(Mesh):
         surf_path="",
         surf_name="",
         node_normals=None,
-        label=None,
         dimension=2,
         init_dict=None,
         init_str=None,
@@ -228,8 +245,6 @@ class MeshVTK(Mesh):
                 surf_name = init_dict["surf_name"]
             if "node_normals" in list(init_dict.keys()):
                 node_normals = init_dict["node_normals"]
-            if "label" in list(init_dict.keys()):
-                label = init_dict["label"]
             if "dimension" in list(init_dict.keys()):
                 dimension = init_dict["dimension"]
         # Set the properties (value check and convertion are done in setter)
@@ -244,7 +259,7 @@ class MeshVTK(Mesh):
         self.surf_name = surf_name
         self.node_normals = node_normals
         # Call Mesh init
-        super(MeshVTK, self).__init__(label=label, dimension=dimension)
+        super(MeshVTK, self).__init__(dimension=dimension)
         # The class is frozen (in Mesh init), for now it's impossible to
         # add new properties
 
@@ -492,7 +507,6 @@ class MeshVTK(Mesh):
             node_normals_val = None
         else:
             node_normals_val = self.node_normals.copy()
-        label_val = self.label
         dimension_val = self.dimension
         # Creates new object of the same type with the copied properties
         obj_copy = type(self)(
@@ -506,7 +520,6 @@ class MeshVTK(Mesh):
             surf_path=surf_path_val,
             surf_name=surf_name_val,
             node_normals=node_normals_val,
-            label=label_val,
             dimension=dimension_val,
         )
         return obj_copy
@@ -712,7 +725,7 @@ class MeshVTK(Mesh):
     node_normals = property(
         fget=_get_node_normals,
         fset=_set_node_normals,
-        doc=u"""Array of normals to nodes (cell vertices)
+        doc=u"""Array of normals to nodes (element vertices)
 
         :Type: ndarray
         """,
