@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from ._frozen import FrozenClass
 
 from ntpath import basename
@@ -20,12 +20,8 @@ from os.path import isfile
 from ._check import CheckTypeError
 import numpy as np
 import random
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Simulation import Simulation
-from .OptiDesignVar import OptiDesignVar
-from .OptiObjective import OptiObjective
-from .OptiConstraint import OptiConstraint
-from .DataKeeper import DataKeeper
 
 
 class OptiProblem(FrozenClass):
@@ -33,9 +29,8 @@ class OptiProblem(FrozenClass):
 
     VERSION = 1
 
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -174,7 +169,7 @@ class OptiProblem(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -187,7 +182,14 @@ class OptiProblem(FrozenClass):
         ):
             diff_list.append(name + ".simu None mismatch")
         elif self.simu is not None:
-            diff_list.extend(self.simu.compare(other.simu, name=name + ".simu"))
+            diff_list.extend(
+                self.simu.compare(
+                    other.simu,
+                    name=name + ".simu",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
+            )
         if (other.design_var is None and self.design_var is not None) or (
             other.design_var is not None and self.design_var is None
         ):
@@ -200,7 +202,10 @@ class OptiProblem(FrozenClass):
             for ii in range(len(other.design_var)):
                 diff_list.extend(
                     self.design_var[ii].compare(
-                        other.design_var[ii], name=name + ".design_var[" + str(ii) + "]"
+                        other.design_var[ii],
+                        name=name + ".design_var[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if (other.obj_func is None and self.obj_func is not None) or (
@@ -215,7 +220,10 @@ class OptiProblem(FrozenClass):
             for ii in range(len(other.obj_func)):
                 diff_list.extend(
                     self.obj_func[ii].compare(
-                        other.obj_func[ii], name=name + ".obj_func[" + str(ii) + "]"
+                        other.obj_func[ii],
+                        name=name + ".obj_func[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if other._eval_func_str != self._eval_func_str:
@@ -232,7 +240,10 @@ class OptiProblem(FrozenClass):
             for ii in range(len(other.constraint)):
                 diff_list.extend(
                     self.constraint[ii].compare(
-                        other.constraint[ii], name=name + ".constraint[" + str(ii) + "]"
+                        other.constraint[ii],
+                        name=name + ".constraint[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         if other._preprocessing_str != self._preprocessing_str:
@@ -251,6 +262,8 @@ class OptiProblem(FrozenClass):
                     self.datakeeper_list[ii].compare(
                         other.datakeeper_list[ii],
                         name=name + ".datakeeper_list[" + str(ii) + "]",
+                        ignore_list=ignore_list,
+                        is_add_value=is_add_value,
                     )
                 )
         # Filter ignore differences
@@ -330,7 +343,7 @@ class OptiProblem(FrozenClass):
                     OptiProblem_dict["obj_func"].append(None)
         if self._eval_func_str is not None:
             OptiProblem_dict["eval_func"] = self._eval_func_str
-        elif "keep_function" in kwargs and kwargs["keep_function"]:
+        elif keep_function:
             OptiProblem_dict["eval_func"] = self.eval_func
         else:
             OptiProblem_dict["eval_func"] = None
@@ -357,7 +370,7 @@ class OptiProblem(FrozenClass):
                     OptiProblem_dict["constraint"].append(None)
         if self._preprocessing_str is not None:
             OptiProblem_dict["preprocessing"] = self._preprocessing_str
-        elif "keep_function" in kwargs and kwargs["keep_function"]:
+        elif keep_function:
             OptiProblem_dict["preprocessing"] = self.preprocessing
         else:
             OptiProblem_dict["preprocessing"] = None
@@ -386,6 +399,58 @@ class OptiProblem(FrozenClass):
         OptiProblem_dict["__class__"] = "OptiProblem"
         return OptiProblem_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.simu is None:
+            simu_val = None
+        else:
+            simu_val = self.simu.copy()
+        if self.design_var is None:
+            design_var_val = None
+        else:
+            design_var_val = list()
+            for obj in self.design_var:
+                design_var_val.append(obj.copy())
+        if self.obj_func is None:
+            obj_func_val = None
+        else:
+            obj_func_val = list()
+            for obj in self.obj_func:
+                obj_func_val.append(obj.copy())
+        if self._eval_func_str is not None:
+            eval_func_val = self._eval_func_str
+        else:
+            eval_func_val = self._eval_func_func
+        if self.constraint is None:
+            constraint_val = None
+        else:
+            constraint_val = list()
+            for obj in self.constraint:
+                constraint_val.append(obj.copy())
+        if self._preprocessing_str is not None:
+            preprocessing_val = self._preprocessing_str
+        else:
+            preprocessing_val = self._preprocessing_func
+        if self.datakeeper_list is None:
+            datakeeper_list_val = None
+        else:
+            datakeeper_list_val = list()
+            for obj in self.datakeeper_list:
+                datakeeper_list_val.append(obj.copy())
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            simu=simu_val,
+            design_var=design_var_val,
+            obj_func=obj_func_val,
+            eval_func=eval_func_val,
+            constraint=constraint_val,
+            preprocessing=preprocessing_val,
+            datakeeper_list=datakeeper_list_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -405,11 +470,18 @@ class OptiProblem(FrozenClass):
     def _set_simu(self, value):
         """setter of simu"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class("pyleecan.Classes", value.get("__class__"), "simu")
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Simulation = import_class("pyleecan.Classes", "Simulation", "simu")
             value = Simulation()
         check_var("simu", value, "Simulation")
         self._simu = value
@@ -438,6 +510,15 @@ class OptiProblem(FrozenClass):
         """setter of design_var"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "design_var"
@@ -471,6 +552,15 @@ class OptiProblem(FrozenClass):
         """setter of obj_func"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "obj_func"
@@ -539,6 +629,15 @@ class OptiProblem(FrozenClass):
         """setter of constraint"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "constraint"
@@ -607,6 +706,15 @@ class OptiProblem(FrozenClass):
         """setter of datakeeper_list"""
         if type(value) is list:
             for ii, obj in enumerate(value):
+                if isinstance(obj, str):  # Load from file
+                    try:
+                        obj = load_init_dict(obj)[1]
+                    except Exception as e:
+                        self.get_logger().error(
+                            "Error while loading " + obj + ", setting None instead"
+                        )
+                        obj = None
+                        value[ii] = None
                 if type(obj) is dict:
                     class_obj = import_class(
                         "pyleecan.Classes", obj.get("__class__"), "datakeeper_list"
