@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .OutInternal import OutInternal
 
 # Import all class method
@@ -23,6 +23,7 @@ except ImportError as error:
     clean = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -40,9 +41,8 @@ class OutMagElmer(OutInternal):
         )
     else:
         clean = clean
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -93,7 +93,7 @@ class OutMagElmer(OutInternal):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -103,9 +103,23 @@ class OutMagElmer(OutInternal):
         diff_list = list()
 
         # Check the properties inherited from OutInternal
-        diff_list.extend(super(OutMagElmer, self).compare(other, name=name))
+        diff_list.extend(
+            super(OutMagElmer, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if other._FEA_dict != self._FEA_dict:
-            diff_list.append(name + ".FEA_dict")
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._FEA_dict)
+                    + ", other="
+                    + str(other._FEA_dict)
+                    + ")"
+                )
+                diff_list.append(name + ".FEA_dict" + val_str)
+            else:
+                diff_list.append(name + ".FEA_dict")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -147,6 +161,18 @@ class OutMagElmer(OutInternal):
         OutMagElmer_dict["__class__"] = "OutMagElmer"
         return OutMagElmer_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.FEA_dict is None:
+            FEA_dict_val = None
+        else:
+            FEA_dict_val = self.FEA_dict.copy()
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(FEA_dict=FEA_dict_val)
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
