@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Surface import Surface
 
 # Import all class method
@@ -63,6 +63,7 @@ except ImportError as error:
     comp_point_ref = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -161,9 +162,8 @@ class PolarArc(Surface):
         )
     else:
         comp_point_ref = comp_point_ref
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -226,7 +226,7 @@ class PolarArc(Surface):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -236,11 +236,45 @@ class PolarArc(Surface):
         diff_list = list()
 
         # Check the properties inherited from Surface
-        diff_list.extend(super(PolarArc, self).compare(other, name=name))
-        if other._angle != self._angle:
-            diff_list.append(name + ".angle")
-        if other._height != self._height:
-            diff_list.append(name + ".height")
+        diff_list.extend(
+            super(PolarArc, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
+        if (
+            other._angle is not None
+            and self._angle is not None
+            and isnan(other._angle)
+            and isnan(self._angle)
+        ):
+            pass
+        elif other._angle != self._angle:
+            if is_add_value:
+                val_str = (
+                    " (self=" + str(self._angle) + ", other=" + str(other._angle) + ")"
+                )
+                diff_list.append(name + ".angle" + val_str)
+            else:
+                diff_list.append(name + ".angle")
+        if (
+            other._height is not None
+            and self._height is not None
+            and isnan(other._height)
+            and isnan(self._height)
+        ):
+            pass
+        elif other._height != self._height:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._height)
+                    + ", other="
+                    + str(other._height)
+                    + ")"
+                )
+                diff_list.append(name + ".height" + val_str)
+            else:
+                diff_list.append(name + ".height")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -280,6 +314,20 @@ class PolarArc(Surface):
         PolarArc_dict["__class__"] = "PolarArc"
         return PolarArc_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        angle_val = self.angle
+        height_val = self.height
+        point_ref_val = self.point_ref
+        label_val = self.label
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            angle=angle_val, height=height_val, point_ref=point_ref_val, label=label_val
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
