@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .ScalarProduct import ScalarProduct
 
 # Import all class method
@@ -23,6 +23,7 @@ except ImportError as error:
     scalar_product = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
 
 
@@ -43,9 +44,8 @@ class ScalarProductL2(ScalarProduct):
         )
     else:
         scalar_product = scalar_product
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -90,7 +90,7 @@ class ScalarProductL2(ScalarProduct):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -100,7 +100,11 @@ class ScalarProductL2(ScalarProduct):
         diff_list = list()
 
         # Check the properties inherited from ScalarProduct
-        diff_list.extend(super(ScalarProductL2, self).compare(other, name=name))
+        diff_list.extend(
+            super(ScalarProductL2, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -136,6 +140,14 @@ class ScalarProductL2(ScalarProduct):
         ScalarProductL2_dict["__class__"] = "ScalarProductL2"
         return ScalarProductL2_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)()
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
