@@ -152,6 +152,16 @@ try:
 except ImportError as error:
     set_label = error
 
+try:
+    from ..Methods.Slot.Slot.is_airgap_active import is_airgap_active
+except ImportError as error:
+    is_airgap_active = error
+
+try:
+    from ..Methods.Slot.Slot.is_full_pitch_active import is_full_pitch_active
+except ImportError as error:
+    is_full_pitch_active = error
+
 
 from numpy import isnan
 from ._check import InitUnKnowClassError
@@ -449,6 +459,29 @@ class Slot(FrozenClass):
         )
     else:
         set_label = set_label
+    # cf Methods.Slot.Slot.is_airgap_active
+    if isinstance(is_airgap_active, ImportError):
+        is_airgap_active = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Slot method is_airgap_active: " + str(is_airgap_active)
+                )
+            )
+        )
+    else:
+        is_airgap_active = is_airgap_active
+    # cf Methods.Slot.Slot.is_full_pitch_active
+    if isinstance(is_full_pitch_active, ImportError):
+        is_full_pitch_active = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use Slot method is_full_pitch_active: "
+                    + str(is_full_pitch_active)
+                )
+            )
+        )
+    else:
+        is_full_pitch_active = is_full_pitch_active
     # generic save method is available in all object
     save = save
     # get_logger method is available in all object
