@@ -67,11 +67,21 @@ try:
 except ImportError as error:
     comp_surface_opening = error
 
+try:
+    from ..Methods.Slot.SlotW14.comp_surface_wedge import comp_surface_wedge
+except ImportError as error:
+    comp_surface_wedge = error
+
 try:
     from ..Methods.Slot.SlotW14.get_surface_active import get_surface_active
 except ImportError as error:
     get_surface_active = error
 
+try:
+    from ..Methods.Slot.SlotW14.get_surface_wedge import get_surface_wedge
+except ImportError as error:
+    get_surface_wedge = error
+
 try:
     from ..Methods.Slot.SlotW14.get_surface_opening import get_surface_opening
 except ImportError as error:
@@ -82,6 +92,11 @@ try:
 except ImportError as error:
     plot_schematics = error
 
+try:
+    from ..Methods.Slot.SlotW14.get_H1 import get_H1
+except ImportError as error:
+    get_H1 = error
+
 
 from numpy import isnan
 from ._check import InitUnKnowClassError
@@ -204,6 +219,18 @@ class SlotW14(Slot):
         )
     else:
         comp_surface_opening = comp_surface_opening
+    # cf Methods.Slot.SlotW14.comp_surface_wedge
+    if isinstance(comp_surface_wedge, ImportError):
+        comp_surface_wedge = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotW14 method comp_surface_wedge: "
+                    + str(comp_surface_wedge)
+                )
+            )
+        )
+    else:
+        comp_surface_wedge = comp_surface_wedge
     # cf Methods.Slot.SlotW14.get_surface_active
     if isinstance(get_surface_active, ImportError):
         get_surface_active = property(
@@ -216,6 +243,18 @@ class SlotW14(Slot):
         )
     else:
         get_surface_active = get_surface_active
+    # cf Methods.Slot.SlotW14.get_surface_wedge
+    if isinstance(get_surface_wedge, ImportError):
+        get_surface_wedge = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use SlotW14 method get_surface_wedge: "
+                    + str(get_surface_wedge)
+                )
+            )
+        )
+    else:
+        get_surface_wedge = get_surface_wedge
     # cf Methods.Slot.SlotW14.get_surface_opening
     if isinstance(get_surface_opening, ImportError):
         get_surface_opening = property(
@@ -239,6 +278,15 @@ class SlotW14(Slot):
         )
     else:
         plot_schematics = plot_schematics
+    # cf Methods.Slot.SlotW14.get_H1
+    if isinstance(get_H1, ImportError):
+        get_H1 = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use SlotW14 method get_H1: " + str(get_H1))
+            )
+        )
+    else:
+        get_H1 = get_H1
     # generic save method is available in all object
     save = save
     # get_logger method is available in all object
@@ -248,9 +296,11 @@ class SlotW14(Slot):
         self,
         W0=0.0122,
         H0=0.001,
-        H1=0.0015,
+        H1=0,
         H3=0.0122,
+        wedge_type=0,
         W3=0.0122,
+        H1_is_rad=False,
         Zs=36,
         wedge_mat=None,
         is_bore=True,
@@ -280,8 +330,12 @@ class SlotW14(Slot):
                 H1 = init_dict["H1"]
             if "H3" in list(init_dict.keys()):
                 H3 = init_dict["H3"]
+            if "wedge_type" in list(init_dict.keys()):
+                wedge_type = init_dict["wedge_type"]
             if "W3" in list(init_dict.keys()):
                 W3 = init_dict["W3"]
+            if "H1_is_rad" in list(init_dict.keys()):
+                H1_is_rad = init_dict["H1_is_rad"]
             if "Zs" in list(init_dict.keys()):
                 Zs = init_dict["Zs"]
             if "wedge_mat" in list(init_dict.keys()):
@@ -293,7 +347,9 @@ class SlotW14(Slot):
         self.H0 = H0
         self.H1 = H1
         self.H3 = H3
+        self.wedge_type = wedge_type
         self.W3 = W3
+        self.H1_is_rad = H1_is_rad
         # Call Slot init
         super(SlotW14, self).__init__(Zs=Zs, wedge_mat=wedge_mat, is_bore=is_bore)
         # The class is frozen (in Slot init), for now it's impossible to
@@ -309,7 +365,9 @@ class SlotW14(Slot):
         SlotW14_str += "H0 = " + str(self.H0) + linesep
         SlotW14_str += "H1 = " + str(self.H1) + linesep
         SlotW14_str += "H3 = " + str(self.H3) + linesep
+        SlotW14_str += "wedge_type = " + str(self.wedge_type) + linesep
         SlotW14_str += "W3 = " + str(self.W3) + linesep
+        SlotW14_str += "H1_is_rad = " + str(self.H1_is_rad) + linesep
         return SlotW14_str
 
     def __eq__(self, other):
@@ -329,8 +387,12 @@ class SlotW14(Slot):
             return False
         if other.H3 != self.H3:
             return False
+        if other.wedge_type != self.wedge_type:
+            return False
         if other.W3 != self.W3:
             return False
+        if other.H1_is_rad != self.H1_is_rad:
+            return False
         return True
 
     def compare(self, other, name="self", ignore_list=None, is_add_value=False):
@@ -400,6 +462,18 @@ class SlotW14(Slot):
                 diff_list.append(name + ".H3" + val_str)
             else:
                 diff_list.append(name + ".H3")
+        if other._wedge_type != self._wedge_type:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._wedge_type)
+                    + ", other="
+                    + str(other._wedge_type)
+                    + ")"
+                )
+                diff_list.append(name + ".wedge_type" + val_str)
+            else:
+                diff_list.append(name + ".wedge_type")
         if (
             other._W3 is not None
             and self._W3 is not None
@@ -413,6 +487,18 @@ class SlotW14(Slot):
                 diff_list.append(name + ".W3" + val_str)
             else:
                 diff_list.append(name + ".W3")
+        if other._H1_is_rad != self._H1_is_rad:
+            if is_add_value:
+                val_str = (
+                    " (self="
+                    + str(self._H1_is_rad)
+                    + ", other="
+                    + str(other._H1_is_rad)
+                    + ")"
+                )
+                diff_list.append(name + ".H1_is_rad" + val_str)
+            else:
+                diff_list.append(name + ".H1_is_rad")
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
@@ -428,7 +514,9 @@ class SlotW14(Slot):
         S += getsizeof(self.H0)
         S += getsizeof(self.H1)
         S += getsizeof(self.H3)
+        S += getsizeof(self.wedge_type)
         S += getsizeof(self.W3)
+        S += getsizeof(self.H1_is_rad)
         return S
 
     def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
@@ -452,7 +540,9 @@ class SlotW14(Slot):
         SlotW14_dict["H0"] = self.H0
         SlotW14_dict["H1"] = self.H1
         SlotW14_dict["H3"] = self.H3
+        SlotW14_dict["wedge_type"] = self.wedge_type
         SlotW14_dict["W3"] = self.W3
+        SlotW14_dict["H1_is_rad"] = self.H1_is_rad
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         SlotW14_dict["__class__"] = "SlotW14"
@@ -466,7 +556,9 @@ class SlotW14(Slot):
         H0_val = self.H0
         H1_val = self.H1
         H3_val = self.H3
+        wedge_type_val = self.wedge_type
         W3_val = self.W3
+        H1_is_rad_val = self.H1_is_rad
         Zs_val = self.Zs
         if self.wedge_mat is None:
             wedge_mat_val = None
@@ -479,7 +571,9 @@ class SlotW14(Slot):
             H0=H0_val,
             H1=H1_val,
             H3=H3_val,
+            wedge_type=wedge_type_val,
             W3=W3_val,
+            H1_is_rad=H1_is_rad_val,
             Zs=Zs_val,
             wedge_mat=wedge_mat_val,
             is_bore=is_bore_val,
@@ -493,7 +587,9 @@ class SlotW14(Slot):
         self.H0 = None
         self.H1 = None
         self.H3 = None
+        self.wedge_type = None
         self.W3 = None
+        self.H1_is_rad = None
         # Set to None the properties inherited from Slot
         super(SlotW14, self)._set_None()
 
@@ -547,7 +643,7 @@ class SlotW14(Slot):
     H1 = property(
         fget=_get_H1,
         fset=_set_H1,
-        doc=u"""Slot intermediate height.
+        doc=u"""height or angle (See Schematics)
 
         :Type: float
         :min: 0
@@ -573,6 +669,25 @@ class SlotW14(Slot):
         """,
     )
 
+    def _get_wedge_type(self):
+        """getter of wedge_type"""
+        return self._wedge_type
+
+    def _set_wedge_type(self, value):
+        """setter of wedge_type"""
+        check_var("wedge_type", value, "int", Vmin=0)
+        self._wedge_type = value
+
+    wedge_type = property(
+        fget=_get_wedge_type,
+        fset=_set_wedge_type,
+        doc=u"""selection type wedge
+
+        :Type: int
+        :min: 0
+        """,
+    )
+
     def _get_W3(self):
         """getter of W3"""
         return self._W3
@@ -591,3 +706,21 @@ class SlotW14(Slot):
         :min: 0
         """,
     )
+
+    def _get_H1_is_rad(self):
+        """getter of H1_is_rad"""
+        return self._H1_is_rad
+
+    def _set_H1_is_rad(self, value):
+        """setter of H1_is_rad"""
+        check_var("H1_is_rad", value, "bool")
+        self._H1_is_rad = value
+
+    H1_is_rad = property(
+        fget=_get_H1_is_rad,
+        fset=_set_H1_is_rad,
+        doc=u"""H1 unit, 0 for m, 1 for rad
+
+        :Type: bool
+        """,
+    )
