@@ -10,9 +10,9 @@ from logging import getLogger
 from ._check import check_var, raise_
 from ..Functions.get_logger import get_logger
 from ..Functions.save import save
-from ..Functions.copy import copy
 from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
+from copy import deepcopy
 from .Surface import Surface
 
 # Import all class method
@@ -68,8 +68,8 @@ except ImportError as error:
     comp_point_ref = error
 
 
+from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Surface import Surface
 
 
 class SurfRing(Surface):
@@ -176,9 +176,8 @@ class SurfRing(Surface):
         )
     else:
         comp_point_ref = comp_point_ref
-    # save and copy methods are available in all object
+    # generic save method is available in all object
     save = save
-    copy = copy
     # get_logger method is available in all object
     get_logger = get_logger
 
@@ -255,7 +254,7 @@ class SurfRing(Surface):
             return False
         return True
 
-    def compare(self, other, name="self", ignore_list=None):
+    def compare(self, other, name="self", ignore_list=None, is_add_value=False):
         """Compare two objects and return list of differences"""
 
         if ignore_list is None:
@@ -265,14 +264,23 @@ class SurfRing(Surface):
         diff_list = list()
 
         # Check the properties inherited from Surface
-        diff_list.extend(super(SurfRing, self).compare(other, name=name))
+        diff_list.extend(
+            super(SurfRing, self).compare(
+                other, name=name, ignore_list=ignore_list, is_add_value=is_add_value
+            )
+        )
         if (other.out_surf is None and self.out_surf is not None) or (
             other.out_surf is not None and self.out_surf is None
         ):
             diff_list.append(name + ".out_surf None mismatch")
         elif self.out_surf is not None:
             diff_list.extend(
-                self.out_surf.compare(other.out_surf, name=name + ".out_surf")
+                self.out_surf.compare(
+                    other.out_surf,
+                    name=name + ".out_surf",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         if (other.in_surf is None and self.in_surf is not None) or (
             other.in_surf is not None and self.in_surf is None
@@ -280,7 +288,12 @@ class SurfRing(Surface):
             diff_list.append(name + ".in_surf None mismatch")
         elif self.in_surf is not None:
             diff_list.extend(
-                self.in_surf.compare(other.in_surf, name=name + ".in_surf")
+                self.in_surf.compare(
+                    other.in_surf,
+                    name=name + ".in_surf",
+                    ignore_list=ignore_list,
+                    is_add_value=is_add_value,
+                )
             )
         # Filter ignore differences
         diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
@@ -335,6 +348,29 @@ class SurfRing(Surface):
         SurfRing_dict["__class__"] = "SurfRing"
         return SurfRing_dict
 
+    def copy(self):
+        """Creates a deepcopy of the object"""
+
+        # Handle deepcopy of all the properties
+        if self.out_surf is None:
+            out_surf_val = None
+        else:
+            out_surf_val = self.out_surf.copy()
+        if self.in_surf is None:
+            in_surf_val = None
+        else:
+            in_surf_val = self.in_surf.copy()
+        point_ref_val = self.point_ref
+        label_val = self.label
+        # Creates new object of the same type with the copied properties
+        obj_copy = type(self)(
+            out_surf=out_surf_val,
+            in_surf=in_surf_val,
+            point_ref=point_ref_val,
+            label=label_val,
+        )
+        return obj_copy
+
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -352,13 +388,20 @@ class SurfRing(Surface):
     def _set_out_surf(self, value):
         """setter of out_surf"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "out_surf"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Surface = import_class("pyleecan.Classes", "Surface", "out_surf")
             value = Surface()
         check_var("out_surf", value, "Surface")
         self._out_surf = value
@@ -382,13 +425,20 @@ class SurfRing(Surface):
     def _set_in_surf(self, value):
         """setter of in_surf"""
         if isinstance(value, str):  # Load from file
-            value = load_init_dict(value)[1]
+            try:
+                value = load_init_dict(value)[1]
+            except Exception as e:
+                self.get_logger().error(
+                    "Error while loading " + value + ", setting None instead"
+                )
+                value = None
         if isinstance(value, dict) and "__class__" in value:
             class_obj = import_class(
                 "pyleecan.Classes", value.get("__class__"), "in_surf"
             )
             value = class_obj(init_dict=value)
         elif type(value) is int and value == -1:  # Default constructor
+            Surface = import_class("pyleecan.Classes", "Surface", "in_surf")
             value = Surface()
         check_var("in_surf", value, "Surface")
         self._in_surf = value
