@@ -20,15 +20,3 @@ class Gen_PVentUD(Ui_PVentUD):
         txt = self.tr(u"""Number of Hole around the circumference""")
         self.si_Zh.setWhatsThis(txt)
         self.si_Zh.setToolTip(txt)
-
-        # Setup of in_Alpha0
-        txt = self.tr(u"""Shift angle of the holes around circumference""")
-        self.in_Alpha0.setWhatsThis(txt)
-        self.in_Alpha0.setToolTip(txt)
-
-        # Setup of lf_Alpha0
-        self.lf_Alpha0.validator().setBottom(0)
-        self.lf_Alpha0.validator().setTop(6.29)
-        txt = self.tr(u"""Shift angle of the holes around circumference""")
-        self.lf_Alpha0.setWhatsThis(txt)
-        self.lf_Alpha0.setToolTip(txt)
