@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from os.path import basename, join, dirname
-
+from os.path import basename, join, dirname, isfile
+from logging import getLogger
+from ....Functions.GUI.log_error import log_error
+from ....loggers import GUI_LOG_NAME
 from PySide2.QtCore import Qt, Signal
 from PySide2.QtWidgets import QFileDialog, QMessageBox, QWidget
 
@@ -12,6 +14,7 @@ from ....GUI.Dialog.DMachineSetup.SPreview.SPreview import SPreview
 from ....GUI.Dialog.DMachineSetup.SSimu.SSimu import SSimu
 from ....definitions import config_dict
 from ....Classes.Machine import Machine
+from ....Classes.ConvertMC import ConvertMC
 
 # Flag for set the enable property of w_nav (List_Widget)
 DISABLE_ITEM = Qt.NoItemFlags
@@ -42,6 +45,8 @@ class DMachineSetup(Ui_DMachineSetup, QWidget):
 
         # Build the interface according to the .ui file
         QWidget.__init__(self)
+        self.setWindowFlag(Qt.WindowMinimizeButtonHint, True)
+        self.setWindowFlag(Qt.WindowMaximizeButtonHint, True)
         self.setupUi(self)
 
         self.is_save_needed = False
@@ -51,9 +56,9 @@ class DMachineSetup(Ui_DMachineSetup, QWidget):
         # Saving arguments
         self.machine = machine
         if machine_path == "":
-            self.machine_path = config_dict["MAIN"]["MACHINE_DIR"]
+            self.machine_path = config_dict["MAIN"]["MACHINE_DIR"].replace("\\", "/")
         else:
-            self.machine_path = machine_path
+            self.machine_path = machine_path.replace("\\", "/")
 
         # Initialize the machine if needed
         if machine is None:
@@ -124,13 +129,24 @@ class DMachineSetup(Ui_DMachineSetup, QWidget):
             save_file_path = QFileDialog.getSaveFileName(
                 self, self.tr("Save file"), def_path, "Json (*.json)"
             )[0]
+        save_file_path = save_file_path.replace("\\", "/")
 
         # Avoid bug due to user closing the popup witout selecting a file
         if save_file_path != "":
             # Set the machine name to match the file name
             self.machine.name = str(basename(str(save_file_path)))[:-5]
             # Save the machine file
-            self.machine.save(save_file_path)
+            getLogger(GUI_LOG_NAME).info(
+                "Saving " + self.machine.name + " in folder " + dirname(save_file_path)
+            )
+            try:
+                self.machine.save(save_file_path)
+            except Exception as e:
+                err_msg = (
+                    "Error while saving machine " + self.machine.name + ":\n" + str(e)
+                )
+                log_error(self, err_msg)
+                return False
             # To update the machine name field (if first page)
             self.set_nav(self.nav_step.currentRow())
             # Update the machine path to remember the last used folder
@@ -163,18 +179,29 @@ class DMachineSetup(Ui_DMachineSetup, QWidget):
         """
         ### TODO: handle material data, i.e. "connect", set new material, etc.
 
-        # Ask the user to select a .json file to load
+        # Ask the user to select a .json or .mot file to load
         load_path = str(
             QFileDialog.getOpenFileName(
-                self, self.tr("Load file"), self.machine_path, "Json (*.json)"
+                self,
+                self.tr("Load file"),
+                self.machine_path,
+                "Machine (*.json *.mot);; all (*.*)",
             )[0]
         )
         if load_path != "":
             try:
                 # Update the machine path to remember the last used folder
                 self.machine_path = dirname(load_path)
+
+                # Load and convert file .mot in obj machine
+                list_path = load_path.split(".")
+                if list_path[-1] == "mot":
+                    conv = ConvertMC()
+                    machine = conv.convert_to_P(load_path)
+
                 # Load and check type of instance
-                machine = load(load_path)
+                else:
+                    machine = load(load_path)
                 if isinstance(machine, Machine):
                     self.machine = machine
                     load_machine_materials(self.material_dict, self.machine)
