@@ -10,7 +10,6 @@ from PySide2.QtGui import *
 from PySide2.QtWidgets import *
 
 from pyleecan.GUI.Tools.HelpButton import HelpButton
-from .....GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect
 
 from pyleecan.GUI.Resources import pyleecan_rc
 
@@ -19,7 +18,7 @@ class Ui_SMSlot(object):
     def setupUi(self, SMSlot):
         if not SMSlot.objectName():
             SMSlot.setObjectName(u"SMSlot")
-        SMSlot.resize(650, 550)
+        SMSlot.resize(827, 644)
         SMSlot.setMinimumSize(QSize(650, 0))
         self.main_layout = QVBoxLayout(SMSlot)
         self.main_layout.setObjectName(u"main_layout")
@@ -31,13 +30,18 @@ class Ui_SMSlot(object):
 
         self.horizontalLayout_2.addWidget(self.b_help)
 
-        self.c_slot_type = QComboBox(SMSlot)
-        self.c_slot_type.addItem("")
-        self.c_slot_type.addItem("")
-        self.c_slot_type.addItem("")
-        self.c_slot_type.setObjectName(u"c_slot_type")
+        self.in_NS_type = QLabel(SMSlot)
+        self.in_NS_type.setObjectName(u"in_NS_type")
 
-        self.horizontalLayout_2.addWidget(self.c_slot_type)
+        self.horizontalLayout_2.addWidget(self.in_NS_type)
+
+        self.c_NS_type = QComboBox(SMSlot)
+        self.c_NS_type.addItem("")
+        self.c_NS_type.addItem("")
+        self.c_NS_type.setObjectName(u"c_NS_type")
+        self.c_NS_type.setMinimumSize(QSize(180, 0))
+
+        self.horizontalLayout_2.addWidget(self.c_NS_type)
 
         self.out_Slot_pitch = QLabel(SMSlot)
         self.out_Slot_pitch.setObjectName(u"out_Slot_pitch")
@@ -52,37 +56,23 @@ class Ui_SMSlot(object):
 
         self.main_layout.addLayout(self.horizontalLayout_2)
 
-        self.horizontalLayout_3 = QHBoxLayout()
-        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
-        self.w_mat = WMatSelect(SMSlot)
-        self.w_mat.setObjectName(u"w_mat")
-
-        self.horizontalLayout_3.addWidget(self.w_mat)
-
-        self.in_type_magnetization = QLabel(SMSlot)
-        self.in_type_magnetization.setObjectName(u"in_type_magnetization")
-
-        self.horizontalLayout_3.addWidget(self.in_type_magnetization)
-
-        self.c_type_magnetization = QComboBox(SMSlot)
-        self.c_type_magnetization.addItem("")
-        self.c_type_magnetization.addItem("")
-        self.c_type_magnetization.addItem("")
-        self.c_type_magnetization.setObjectName(u"c_type_magnetization")
-
-        self.horizontalLayout_3.addWidget(self.c_type_magnetization)
-
-        self.main_layout.addLayout(self.horizontalLayout_3)
-
-        self.w_slot = QWidget(SMSlot)
-        self.w_slot.setObjectName(u"w_slot")
+        self.tab_slot = QTabWidget(SMSlot)
+        self.tab_slot.setObjectName(u"tab_slot")
         sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
-        sizePolicy.setHeightForWidth(self.w_slot.sizePolicy().hasHeightForWidth())
-        self.w_slot.setSizePolicy(sizePolicy)
+        sizePolicy.setHeightForWidth(self.tab_slot.sizePolicy().hasHeightForWidth())
+        self.tab_slot.setSizePolicy(sizePolicy)
+        self.tab_slot.setMinimumSize(QSize(770, 550))
+        self.tab_slot.setTabsClosable(False)
 
-        self.main_layout.addWidget(self.w_slot)
+        self.main_layout.addWidget(self.tab_slot)
+
+        self.verticalSpacer = QSpacerItem(
+            20, 1, QSizePolicy.Minimum, QSizePolicy.Minimum
+        )
+
+        self.main_layout.addItem(self.verticalSpacer)
 
         self.horizontalLayout = QHBoxLayout()
         self.horizontalLayout.setObjectName(u"horizontalLayout")
@@ -111,6 +101,8 @@ class Ui_SMSlot(object):
 
         self.retranslateUi(SMSlot)
 
+        self.tab_slot.setCurrentIndex(-1)
+
         QMetaObject.connectSlotsByName(SMSlot)
 
     # setupUi
@@ -118,32 +110,22 @@ class Ui_SMSlot(object):
     def retranslateUi(self, SMSlot):
         SMSlot.setWindowTitle(QCoreApplication.translate("SMSlot", u"Form", None))
         self.b_help.setText("")
-        self.c_slot_type.setItemText(
-            0, QCoreApplication.translate("SMSlot", u"Slot Type 10", None)
+        self.in_NS_type.setText(
+            QCoreApplication.translate("SMSlot", u"Pole distribution", None)
         )
-        self.c_slot_type.setItemText(
-            1, QCoreApplication.translate("SMSlot", u"Slot Type 11", None)
+        self.c_NS_type.setItemText(
+            0, QCoreApplication.translate("SMSlot", u"Even (default)", None)
         )
-        self.c_slot_type.setItemText(
-            2, QCoreApplication.translate("SMSlot", u"Slot Type 12", None)
+        self.c_NS_type.setItemText(
+            1, QCoreApplication.translate("SMSlot", u"North different than South", None)
         )
 
+        self.c_NS_type.setCurrentText(
+            QCoreApplication.translate("SMSlot", u"Even (default)", None)
+        )
         self.out_Slot_pitch.setText(
             QCoreApplication.translate("SMSlot", u"p = ? Slot pitch = 1.35 rad", None)
         )
-        self.in_type_magnetization.setText(
-            QCoreApplication.translate("SMSlot", u"type_magnetization", None)
-        )
-        self.c_type_magnetization.setItemText(
-            0, QCoreApplication.translate("SMSlot", u"Radial", None)
-        )
-        self.c_type_magnetization.setItemText(
-            1, QCoreApplication.translate("SMSlot", u"Parallel", None)
-        )
-        self.c_type_magnetization.setItemText(
-            2, QCoreApplication.translate("SMSlot", u"HallBach", None)
-        )
-
         self.b_plot.setText(QCoreApplication.translate("SMSlot", u"Preview", None))
         self.b_previous.setText(QCoreApplication.translate("SMSlot", u"Previous", None))
         self.b_next.setText(QCoreApplication.translate("SMSlot", u"Next", None))
