@@ -33,6 +33,9 @@ class Ui_SWPole(object):
         self.c_slot_type = QComboBox(SWPole)
         self.c_slot_type.addItem("")
         self.c_slot_type.addItem("")
+        self.c_slot_type.addItem("")
+        self.c_slot_type.addItem("")
+        self.c_slot_type.addItem("")
         self.c_slot_type.setObjectName(u"c_slot_type")
 
         self.horizontalLayout_2.addWidget(self.c_slot_type)
@@ -105,6 +108,15 @@ class Ui_SWPole(object):
         self.c_slot_type.setItemText(
             1, QCoreApplication.translate("SWPole", u"Pole Type 61", None)
         )
+        self.c_slot_type.setItemText(
+            2, QCoreApplication.translate("SWPole", u"Pole Type 62", None)
+        )
+        self.c_slot_type.setItemText(
+            3, QCoreApplication.translate("SWPole", u"Pole Type 63", None)
+        )
+        self.c_slot_type.setItemText(
+            4, QCoreApplication.translate("SWPole", u"pole Type 29", None)
+        )
 
         self.in_Zs.setText(QCoreApplication.translate("SWPole", u"Zs = 2*p = ", None))
         self.out_Slot_pitch.setText(
