@@ -20,13 +20,13 @@ class Ui_PWSlot11(object):
     def setupUi(self, PWSlot11):
         if not PWSlot11.objectName():
             PWSlot11.setObjectName(u"PWSlot11")
-        PWSlot11.resize(1282, 470)
+        PWSlot11.resize(924, 515)
         PWSlot11.setMinimumSize(QSize(630, 470))
         PWSlot11.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PWSlot11)
         self.horizontalLayout.setObjectName(u"horizontalLayout")
-        self.verticalLayout_3 = QVBoxLayout()
-        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
+        self.verticalLayout_2 = QVBoxLayout()
+        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
         self.img_slot = QLabel(PWSlot11)
         self.img_slot.setObjectName(u"img_slot")
         sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -36,12 +36,12 @@ class Ui_PWSlot11(object):
         self.img_slot.setSizePolicy(sizePolicy)
         self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW11_wind.png")
+            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW11_wind_ext_stator.png")
         )
         self.img_slot.setScaledContents(False)
         self.img_slot.setAlignment(Qt.AlignCenter)
 
-        self.verticalLayout_3.addWidget(self.img_slot)
+        self.verticalLayout_2.addWidget(self.img_slot)
 
         self.txt_constraint = QTextEdit(PWSlot11)
         self.txt_constraint.setObjectName(u"txt_constraint")
@@ -54,13 +54,14 @@ class Ui_PWSlot11(object):
         self.txt_constraint.setSizePolicy(sizePolicy1)
         self.txt_constraint.setMaximumSize(QSize(16777215, 100))
         self.txt_constraint.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
+        self.txt_constraint.setUndoRedoEnabled(True)
         self.txt_constraint.setTextInteractionFlags(
             Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
         )
 
-        self.verticalLayout_3.addWidget(self.txt_constraint)
+        self.verticalLayout_2.addWidget(self.txt_constraint)
 
-        self.horizontalLayout.addLayout(self.verticalLayout_3)
+        self.horizontalLayout.addLayout(self.verticalLayout_2)
 
         self.scrollArea = QScrollArea(PWSlot11)
         self.scrollArea.setObjectName(u"scrollArea")
@@ -69,120 +70,139 @@ class Ui_PWSlot11(object):
         self.scrollArea.setWidgetResizable(True)
         self.scrollAreaWidgetContents = QWidget()
         self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
-        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 446))
-        self.verticalLayout_2 = QVBoxLayout(self.scrollAreaWidgetContents)
-        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
+        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 491))
+        self.verticalLayout_3 = QVBoxLayout(self.scrollAreaWidgetContents)
+        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
+        self.is_cst_tooth = QCheckBox(self.scrollAreaWidgetContents)
+        self.is_cst_tooth.setObjectName(u"is_cst_tooth")
+
+        self.verticalLayout_3.addWidget(self.is_cst_tooth)
+
         self.gridLayout = QGridLayout()
+        self.gridLayout.setSpacing(7)
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_W0 = QLabel(self.scrollAreaWidgetContents)
-        self.in_W0.setObjectName(u"in_W0")
+        self.lf_H1 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_H1.setObjectName(u"lf_H1")
 
-        self.gridLayout.addWidget(self.in_W0, 0, 0, 1, 1)
+        self.gridLayout.addWidget(self.lf_H1, 5, 1, 1, 1)
 
-        self.lf_W0 = FloatEdit(self.scrollAreaWidgetContents)
-        self.lf_W0.setObjectName(u"lf_W0")
+        self.in_H1 = QLabel(self.scrollAreaWidgetContents)
+        self.in_H1.setObjectName(u"in_H1")
 
-        self.gridLayout.addWidget(self.lf_W0, 0, 1, 1, 1)
+        self.gridLayout.addWidget(self.in_H1, 5, 0, 1, 1)
 
-        self.unit_W0 = QLabel(self.scrollAreaWidgetContents)
-        self.unit_W0.setObjectName(u"unit_W0")
+        self.c_H1_unit = QComboBox(self.scrollAreaWidgetContents)
+        self.c_H1_unit.setObjectName(u"c_H1_unit")
+        self.c_H1_unit.setEditable(True)
 
-        self.gridLayout.addWidget(self.unit_W0, 0, 2, 1, 1)
+        self.gridLayout.addWidget(self.c_H1_unit, 5, 4, 1, 1)
+
+        self.lf_H0 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_H0.setObjectName(u"lf_H0")
+
+        self.gridLayout.addWidget(self.lf_H0, 4, 1, 1, 1)
 
         self.in_W1 = QLabel(self.scrollAreaWidgetContents)
         self.in_W1.setObjectName(u"in_W1")
 
         self.gridLayout.addWidget(self.in_W1, 1, 0, 1, 1)
 
-        self.lf_W1 = FloatEdit(self.scrollAreaWidgetContents)
-        self.lf_W1.setObjectName(u"lf_W1")
+        self.in_W3 = QLabel(self.scrollAreaWidgetContents)
+        self.in_W3.setObjectName(u"in_W3")
 
-        self.gridLayout.addWidget(self.lf_W1, 1, 1, 1, 1)
+        self.gridLayout.addWidget(self.in_W3, 3, 0, 1, 1)
 
-        self.unit_W1 = QLabel(self.scrollAreaWidgetContents)
-        self.unit_W1.setObjectName(u"unit_W1")
+        self.in_H2 = QLabel(self.scrollAreaWidgetContents)
+        self.in_H2.setObjectName(u"in_H2")
 
-        self.gridLayout.addWidget(self.unit_W1, 1, 2, 1, 1)
+        self.gridLayout.addWidget(self.in_H2, 6, 0, 1, 1)
 
         self.in_W2 = QLabel(self.scrollAreaWidgetContents)
         self.in_W2.setObjectName(u"in_W2")
 
         self.gridLayout.addWidget(self.in_W2, 2, 0, 1, 1)
 
+        self.lf_W0 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_W0.setObjectName(u"lf_W0")
+
+        self.gridLayout.addWidget(self.lf_W0, 0, 1, 1, 1)
+
         self.lf_W2 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_W2.setObjectName(u"lf_W2")
 
         self.gridLayout.addWidget(self.lf_W2, 2, 1, 1, 1)
 
-        self.unit_W2 = QLabel(self.scrollAreaWidgetContents)
-        self.unit_W2.setObjectName(u"unit_W2")
+        self.unit_W1 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_W1.setObjectName(u"unit_W1")
 
-        self.gridLayout.addWidget(self.unit_W2, 2, 2, 1, 1)
+        self.gridLayout.addWidget(self.unit_W1, 1, 4, 1, 1)
+
+        self.lf_W1 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_W1.setObjectName(u"lf_W1")
+
+        self.gridLayout.addWidget(self.lf_W1, 1, 1, 1, 1)
 
         self.in_H0 = QLabel(self.scrollAreaWidgetContents)
         self.in_H0.setObjectName(u"in_H0")
 
-        self.gridLayout.addWidget(self.in_H0, 3, 0, 1, 1)
-
-        self.lf_H0 = FloatEdit(self.scrollAreaWidgetContents)
-        self.lf_H0.setObjectName(u"lf_H0")
-
-        self.gridLayout.addWidget(self.lf_H0, 3, 1, 1, 1)
-
-        self.unit_H0 = QLabel(self.scrollAreaWidgetContents)
-        self.unit_H0.setObjectName(u"unit_H0")
-
-        self.gridLayout.addWidget(self.unit_H0, 3, 2, 1, 1)
-
-        self.in_H1 = QLabel(self.scrollAreaWidgetContents)
-        self.in_H1.setObjectName(u"in_H1")
-
-        self.gridLayout.addWidget(self.in_H1, 4, 0, 1, 1)
-
-        self.lf_H1 = FloatEdit(self.scrollAreaWidgetContents)
-        self.lf_H1.setObjectName(u"lf_H1")
-
-        self.gridLayout.addWidget(self.lf_H1, 4, 1, 1, 1)
-
-        self.c_H1_unit = QComboBox(self.scrollAreaWidgetContents)
-        self.c_H1_unit.addItem("")
-        self.c_H1_unit.addItem("")
-        self.c_H1_unit.addItem("")
-        self.c_H1_unit.setObjectName(u"c_H1_unit")
-
-        self.gridLayout.addWidget(self.c_H1_unit, 4, 2, 1, 1)
-
-        self.in_H2 = QLabel(self.scrollAreaWidgetContents)
-        self.in_H2.setObjectName(u"in_H2")
-
-        self.gridLayout.addWidget(self.in_H2, 5, 0, 1, 1)
-
-        self.lf_H2 = FloatEdit(self.scrollAreaWidgetContents)
-        self.lf_H2.setObjectName(u"lf_H2")
-
-        self.gridLayout.addWidget(self.lf_H2, 5, 1, 1, 1)
+        self.gridLayout.addWidget(self.in_H0, 4, 0, 1, 1)
 
         self.unit_H2 = QLabel(self.scrollAreaWidgetContents)
         self.unit_H2.setObjectName(u"unit_H2")
 
-        self.gridLayout.addWidget(self.unit_H2, 5, 2, 1, 1)
+        self.gridLayout.addWidget(self.unit_H2, 6, 4, 1, 1)
+
+        self.in_W0 = QLabel(self.scrollAreaWidgetContents)
+        self.in_W0.setObjectName(u"in_W0")
+
+        self.gridLayout.addWidget(self.in_W0, 0, 0, 1, 1)
+
+        self.lf_W3 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_W3.setObjectName(u"lf_W3")
+
+        self.gridLayout.addWidget(self.lf_W3, 3, 1, 1, 1)
+
+        self.unit_W0 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_W0.setObjectName(u"unit_W0")
+
+        self.gridLayout.addWidget(self.unit_W0, 0, 4, 1, 1)
+
+        self.unit_W2 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_W2.setObjectName(u"unit_W2")
+
+        self.gridLayout.addWidget(self.unit_W2, 2, 4, 1, 1)
+
+        self.unit_H0 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_H0.setObjectName(u"unit_H0")
+
+        self.gridLayout.addWidget(self.unit_H0, 4, 4, 1, 1)
+
+        self.lf_H2 = FloatEdit(self.scrollAreaWidgetContents)
+        self.lf_H2.setObjectName(u"lf_H2")
+
+        self.gridLayout.addWidget(self.lf_H2, 6, 1, 1, 1)
+
+        self.unit_W3 = QLabel(self.scrollAreaWidgetContents)
+        self.unit_W3.setObjectName(u"unit_W3")
+
+        self.gridLayout.addWidget(self.unit_W3, 3, 4, 1, 1)
 
         self.in_R1 = QLabel(self.scrollAreaWidgetContents)
         self.in_R1.setObjectName(u"in_R1")
 
-        self.gridLayout.addWidget(self.in_R1, 6, 0, 1, 1)
+        self.gridLayout.addWidget(self.in_R1, 7, 0, 1, 1)
 
         self.lf_R1 = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_R1.setObjectName(u"lf_R1")
 
-        self.gridLayout.addWidget(self.lf_R1, 6, 1, 1, 1)
+        self.gridLayout.addWidget(self.lf_R1, 7, 1, 1, 1)
 
         self.unit_R1 = QLabel(self.scrollAreaWidgetContents)
         self.unit_R1.setObjectName(u"unit_R1")
 
-        self.gridLayout.addWidget(self.unit_R1, 6, 2, 1, 1)
+        self.gridLayout.addWidget(self.unit_R1, 7, 4, 1, 1)
 
-        self.verticalLayout_2.addLayout(self.gridLayout)
+        self.verticalLayout_3.addLayout(self.gridLayout)
 
         self.g_wedge = QGroupBox(self.scrollAreaWidgetContents)
         self.g_wedge.setObjectName(u"g_wedge")
@@ -196,18 +216,18 @@ class Ui_PWSlot11(object):
 
         self.verticalLayout.addWidget(self.w_wedge_mat)
 
-        self.verticalLayout_2.addWidget(self.g_wedge)
+        self.verticalLayout_3.addWidget(self.g_wedge)
 
         self.verticalSpacer = QSpacerItem(
             20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
         )
 
-        self.verticalLayout_2.addItem(self.verticalSpacer)
+        self.verticalLayout_3.addItem(self.verticalSpacer)
 
         self.w_out = WWSlotOut(self.scrollAreaWidgetContents)
         self.w_out.setObjectName(u"w_out")
 
-        self.verticalLayout_2.addWidget(self.w_out)
+        self.verticalLayout_3.addWidget(self.w_out)
 
         self.scrollArea.setWidget(self.scrollAreaWidgetContents)
 
@@ -215,12 +235,16 @@ class Ui_PWSlot11(object):
 
         QWidget.setTabOrder(self.lf_W0, self.lf_W1)
         QWidget.setTabOrder(self.lf_W1, self.lf_W2)
-        QWidget.setTabOrder(self.lf_W2, self.lf_H0)
+        QWidget.setTabOrder(self.lf_W2, self.lf_W3)
+        QWidget.setTabOrder(self.lf_W3, self.lf_H0)
         QWidget.setTabOrder(self.lf_H0, self.lf_H1)
-        QWidget.setTabOrder(self.lf_H1, self.c_H1_unit)
-        QWidget.setTabOrder(self.c_H1_unit, self.lf_H2)
+        QWidget.setTabOrder(self.lf_H1, self.lf_H2)
         QWidget.setTabOrder(self.lf_H2, self.lf_R1)
-        QWidget.setTabOrder(self.lf_R1, self.txt_constraint)
+        QWidget.setTabOrder(self.lf_R1, self.g_wedge)
+        QWidget.setTabOrder(self.g_wedge, self.c_H1_unit)
+        QWidget.setTabOrder(self.c_H1_unit, self.is_cst_tooth)
+        QWidget.setTabOrder(self.is_cst_tooth, self.scrollArea)
+        QWidget.setTabOrder(self.scrollArea, self.txt_constraint)
 
         self.retranslateUi(PWSlot11)
 
@@ -239,34 +263,32 @@ class Ui_PWSlot11(object):
                 "p, li { white-space: pre-wrap; }\n"
                 "</style></head><body style=\" font-family:'DejaVu Sans'; font-size:7.8pt; font-weight:400; font-style:normal;\">\n"
                 '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'DejaVu Sans\'; font-size:10pt; font-weight:600; text-decoration: underline;">Constraints :</span></p>\n'
-                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'DejaVu Sans\'; font-size:10pt;">W0 \u2264 W1</span></p>\n'
                 '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'DejaVu Sans\'; font-size:10pt;">2 \u00d7 R1 \u2264 W2</span></p>\n'
+                '<p align="center" style=" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'DejaVu Sans\'; font-size:10pt;">W0 \u2264 W1</span></p>\n'
                 '<p align="center" style=" m'
                 'argin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"><span style=" font-family:\'DejaVu Sans\'; font-size:10pt;">R1 \u2264 H2</span></p></body></html>',
                 None,
             )
         )
+        self.is_cst_tooth.setText(
+            QCoreApplication.translate("PWSlot11", u"Constant Tooth Width", None)
+        )
+        self.in_H1.setText(QCoreApplication.translate("PWSlot11", u"H1", None))
+        self.c_H1_unit.setCurrentText(
+            QCoreApplication.translate("PWSlot11", u"[m]", None)
+        )
+        self.in_W1.setText(QCoreApplication.translate("PWSlot11", u"W1", None))
+        self.in_W3.setText(QCoreApplication.translate("PWSlot11", u"W3", None))
+        self.in_H2.setText(QCoreApplication.translate("PWSlot11", u"H2", None))
+        self.in_W2.setText(QCoreApplication.translate("PWSlot11", u"W2", None))
+        self.unit_W1.setText(QCoreApplication.translate("PWSlot11", u"m", None))
+        self.in_H0.setText(QCoreApplication.translate("PWSlot11", u"H0", None))
+        self.unit_H2.setText(QCoreApplication.translate("PWSlot11", u"m", None))
         self.in_W0.setText(QCoreApplication.translate("PWSlot11", u"W0", None))
         self.unit_W0.setText(QCoreApplication.translate("PWSlot11", u"m", None))
-        self.in_W1.setText(QCoreApplication.translate("PWSlot11", u"W1", None))
-        self.unit_W1.setText(QCoreApplication.translate("PWSlot11", u"m", None))
-        self.in_W2.setText(QCoreApplication.translate("PWSlot11", u"W2", None))
         self.unit_W2.setText(QCoreApplication.translate("PWSlot11", u"m", None))
-        self.in_H0.setText(QCoreApplication.translate("PWSlot11", u"H0", None))
         self.unit_H0.setText(QCoreApplication.translate("PWSlot11", u"m", None))
-        self.in_H1.setText(QCoreApplication.translate("PWSlot11", u"H1", None))
-        self.c_H1_unit.setItemText(
-            0, QCoreApplication.translate("PWSlot11", u"[m]", None)
-        )
-        self.c_H1_unit.setItemText(
-            1, QCoreApplication.translate("PWSlot11", u"[rad]", None)
-        )
-        self.c_H1_unit.setItemText(
-            2, QCoreApplication.translate("PWSlot11", u"[deg]", None)
-        )
-
-        self.in_H2.setText(QCoreApplication.translate("PWSlot11", u"H2", None))
-        self.unit_H2.setText(QCoreApplication.translate("PWSlot11", u"m", None))
+        self.unit_W3.setText(QCoreApplication.translate("PWSlot11", u"m", None))
         self.in_R1.setText(QCoreApplication.translate("PWSlot11", u"R1", None))
         self.unit_R1.setText(QCoreApplication.translate("PWSlot11", u"m", None))
         self.g_wedge.setTitle(QCoreApplication.translate("PWSlot11", u"Wedge", None))
