@@ -8,6 +8,8 @@ from ......Classes.SlotW12 import SlotW12
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot12.Gen_PWSlot12 import Gen_PWSlot12
 from ......Methods.Slot.Slot import SlotCheckError
+from ......GUI.Resources import pixmap_dict
+
 
 translate = PySide2.QtCore.QCoreApplication.translate
 
@@ -82,17 +84,15 @@ class PWSlot12(Gen_PWSlot12, QWidget):
     def set_wedge(self):
         """Setup the slot wedge according to the GUI"""
         if self.g_wedge.isChecked():
-            self.w_wedge_mat.show()
             self.img_slot.setPixmap(
-                QPixmap(u":/images/images/MachineSetup/WSlot/SlotW12_wedge_full.png")
+                QPixmap(pixmap_dict["SlotW12_wedge_full_ext_stator"])
             )
             self.w_wedge_mat.update(self.slot, "wedge_mat", self.material_dict)
         else:
-            self.w_wedge_mat.hide()
             self.slot.wedge_mat = None
-            self.img_slot.setPixmap(
-                QPixmap(u":/images/images/MachineSetup/WSlot/SlotW12_wind.png")
-            )
+            self.img_slot.setPixmap(QPixmap(pixmap_dict["SlotW12_wind_ext_stator"]))
+        # Notify the machine GUI that the machine has changed
+        self.saveNeeded.emit()
 
     def set_R1(self):
         """Signal to update the value of R1 according to the line edit
