@@ -36,7 +36,9 @@ class Ui_PWSlot15(object):
         self.img_slot.setSizePolicy(sizePolicy)
         self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW15_wedge_full.png")
+            QPixmap(
+                u":/images/images/MachineSetup/WSlot/SlotW15_wedge_full_ext_stator.png"
+            )
         )
         self.img_slot.setScaledContents(False)
         self.img_slot.setAlignment(Qt.AlignCenter)
