@@ -36,7 +36,7 @@ class Ui_PWSlot16(object):
         self.img_slot.setSizePolicy(sizePolicy)
         self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW16_wind.png")
+            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW16_wind_int_stator.png")
         )
         self.img_slot.setScaledContents(False)
         self.img_slot.setAlignment(Qt.AlignCenter)
