@@ -7,9 +7,10 @@ from PySide2.QtWidgets import QWidget
 from PySide2.QtGui import QPixmap
 from ......Classes.SlotW21 import SlotW21
 from ......GUI import gui_option
-
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot21.Gen_PWSlot21 import Gen_PWSlot21
 from ......Methods.Slot.Slot import SlotCheckError
+from ......GUI.Resources import pixmap_dict
+
 
 translate = PySide2.QtCore.QCoreApplication.translate
 
@@ -77,7 +78,7 @@ class PWSlot21(Gen_PWSlot21, QWidget):
         # Update the unit combobox with the current m unit name
         self.c_H1_unit.clear()
         self.c_H1_unit.addItems(
-            ["[" + gui_option.unit.get_m_name() + "]", "[rad]", "[deg]"]
+            ["[" + gui_option.unit.get_m_name() + "]", "[rad]", "[°]"]
         )
         if self.slot.H1_is_rad:  # rad
             self.c_H1_unit.setCurrentIndex(1)
@@ -112,17 +113,15 @@ class PWSlot21(Gen_PWSlot21, QWidget):
     def set_wedge(self):
         """Setup the slot wedge according to the GUI"""
         if self.g_wedge.isChecked():
-            self.w_wedge_mat.show()
             self.img_slot.setPixmap(
-                QPixmap(u":/images/images/MachineSetup/WSlot/SlotW21_wedge_full.png")
+                QPixmap(pixmap_dict["SlotW21_wedge_full_ext_stator"])
             )
             self.w_wedge_mat.update(self.slot, "wedge_mat", self.material_dict)
         else:
-            self.w_wedge_mat.hide()
             self.slot.wedge_mat = None
-            self.img_slot.setPixmap(
-                QPixmap(u":/images/images/MachineSetup/WSlot/SlotW21_wind.png")
-            )
+            self.img_slot.setPixmap(QPixmap(pixmap_dict["SlotW21_wind_ext_stator"]))
+        # Notify the machine GUI that the machine has changed
+        self.saveNeeded.emit()
 
     def set_W0(self):
         """Signal to update the value of W0 according to the line edit
@@ -184,12 +183,15 @@ class PWSlot21(Gen_PWSlot21, QWidget):
         self : PWSlot21
             A PWSlot21 object
         """
-        if self.c_H1_unit.currentIndex() == 0:  # m or mm
-            self.slot.H1 = gui_option.unit.set_m(self.lf_H1.value())
-        elif self.c_H1_unit.currentIndex() == 1:  # rad
-            self.slot.H1 = self.lf_H1.value()
-        else:  # deg
-            self.slot.H1 = self.lf_H1.value() / 180 * pi
+        if self.lf_H1.value() is not None:
+            if self.c_H1_unit.currentIndex() == 0:  # m or mm
+                self.slot.H1 = gui_option.unit.set_m(self.lf_H1.value())
+            elif self.c_H1_unit.currentIndex() == 1:  # rad
+                self.slot.H1 = self.lf_H1.value()
+            else:  # °
+                self.slot.H1 = self.lf_H1.value() / 180 * pi
+        else:
+            self.slot.H1 = None
         self.w_out.comp_output()
         # Notify the machine GUI that the machine has changed
         self.saveNeeded.emit()
@@ -206,7 +208,7 @@ class PWSlot21(Gen_PWSlot21, QWidget):
         """
         self.slot.H1_is_rad = bool(value)
         if self.lf_H1.text() != "":
-            self.set_H1()  # Update for deg if needed and call comp_output
+            self.set_H1()  # Update for ° if needed and call comp_output
         # Notify the machine GUI that the machine has changed
         self.saveNeeded.emit()
 
