@@ -8,6 +8,8 @@ from ......Classes.SlotW29 import SlotW29
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot29.Gen_PWSlot29 import Gen_PWSlot29
 from ......Methods.Slot.Slot import SlotCheckError
+from ......GUI.Resources import pixmap_dict
+
 
 translate = PySide2.QtCore.QCoreApplication.translate
 
@@ -81,6 +83,20 @@ class PWSlot29(Gen_PWSlot29, QWidget):
             self.w_wedge_mat.def_mat = "M400-50A"
         self.set_wedge()
 
+        # Update the combobox
+        self.c_wedge_type.clear()
+
+        self.c_wedge_type.addItems(["Full opening", "Standard"])
+        if self.slot.wedge_type == None:
+            self.slot.wedge_type = 0
+
+        elif self.slot.wedge_type == 1:
+            self.img_slot.setPixmap(
+                QPixmap(pixmap_dict["SlotW29_wedge_type_1_ext_stator"])
+            )
+
+        self.c_wedge_type.setCurrentIndex(self.slot.wedge_type)
+
         # Display the main output of the slot (surface, height...)
         self.w_out.comp_output()
 
@@ -92,21 +108,38 @@ class PWSlot29(Gen_PWSlot29, QWidget):
         self.lf_H1.editingFinished.connect(self.set_H1)
         self.lf_H2.editingFinished.connect(self.set_H2)
         self.g_wedge.toggled.connect(self.set_wedge)
+        self.c_wedge_type.currentIndexChanged.connect(self.set_type_wedge)
 
     def set_wedge(self):
         """Setup the slot wedge according to the GUI"""
         if self.g_wedge.isChecked():
-            self.w_wedge_mat.show()
             self.img_slot.setPixmap(
-                QPixmap(u":/images/images/MachineSetup/WSlot/SlotW29_wedge_full.png")
+                QPixmap(pixmap_dict["SlotW29_wedge_full_ext_stator"])
             )
             self.w_wedge_mat.update(self.slot, "wedge_mat", self.material_dict)
         else:
-            self.w_wedge_mat.hide()
             self.slot.wedge_mat = None
+            self.c_wedge_type.setCurrentIndex(0)
+
+            self.img_slot.setPixmap(QPixmap(pixmap_dict["SlotW29_wind_ext_stator"]))
+        # Notify the machine GUI that the machine has changed
+        self.saveNeeded.emit()
+
+    def set_type_wedge(self):
+        if self.c_wedge_type.currentIndex() == 1:
             self.img_slot.setPixmap(
-                QPixmap(u":/images/images/MachineSetup/WSlot/SlotW29_wind.png")
+                QPixmap(pixmap_dict["SlotW29_wedge_type_1_ext_stator"])
             )
+            self.slot.wedge_type = 1
+
+        if self.c_wedge_type.currentIndex() == 0:
+            self.img_slot.setPixmap(
+                QPixmap(pixmap_dict["SlotW29_wedge_full_ext_stator"])
+            )
+            self.slot.wedge_type = 0
+
+        # Notify the machine GUI that the machine has changed
+        self.saveNeeded.emit()
 
     def set_W0(self):
         """Signal to update the value of W0 according to the line edit
