@@ -10,8 +10,9 @@ from PySide2.QtGui import *
 from PySide2.QtWidgets import *
 
 from ......GUI.Dialog.DMachineSetup.SWSlot.WWSlotOut.WWSlotOut import WWSlotOut
-from ......GUI.Tools.WPathSelector.WPathSelectorV import WPathSelectorV
 from ......GUI.Tools.MPLCanvas import MPLCanvas
+from ......GUI.Dialog.DMatLib.WMatSelect.WMatSelectV import WMatSelectV
+from ......GUI.Tools.WPathSelector.WPathSelectorV import WPathSelectorV
 
 from pyleecan.GUI.Resources import pyleecan_rc
 
@@ -38,12 +39,12 @@ class Ui_PWSlotUD(object):
         self.scrollAreaWidgetContents = QWidget()
         self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
         self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 416))
-        self.verticalLayout = QVBoxLayout(self.scrollAreaWidgetContents)
-        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.verticalLayout_2 = QVBoxLayout(self.scrollAreaWidgetContents)
+        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
         self.b_dxf = QPushButton(self.scrollAreaWidgetContents)
         self.b_dxf.setObjectName(u"b_dxf")
 
-        self.verticalLayout.addWidget(self.b_dxf)
+        self.verticalLayout_2.addWidget(self.b_dxf)
 
         self.w_path_json = WPathSelectorV(self.scrollAreaWidgetContents)
         self.w_path_json.setObjectName(u"w_path_json")
@@ -53,18 +54,32 @@ class Ui_PWSlotUD(object):
         sizePolicy.setHeightForWidth(self.w_path_json.sizePolicy().hasHeightForWidth())
         self.w_path_json.setSizePolicy(sizePolicy)
 
-        self.verticalLayout.addWidget(self.w_path_json)
+        self.verticalLayout_2.addWidget(self.w_path_json)
+
+        self.g_wedge = QGroupBox(self.scrollAreaWidgetContents)
+        self.g_wedge.setObjectName(u"g_wedge")
+        self.g_wedge.setCheckable(True)
+        self.g_wedge.setChecked(False)
+        self.verticalLayout = QVBoxLayout(self.g_wedge)
+        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.w_wedge_mat = WMatSelectV(self.g_wedge)
+        self.w_wedge_mat.setObjectName(u"w_wedge_mat")
+        self.w_wedge_mat.setMinimumSize(QSize(100, 0))
+
+        self.verticalLayout.addWidget(self.w_wedge_mat)
+
+        self.verticalLayout_2.addWidget(self.g_wedge)
 
         self.verticalSpacer = QSpacerItem(
             20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
         )
 
-        self.verticalLayout.addItem(self.verticalSpacer)
+        self.verticalLayout_2.addItem(self.verticalSpacer)
 
         self.w_out = WWSlotOut(self.scrollAreaWidgetContents)
         self.w_out.setObjectName(u"w_out")
 
-        self.verticalLayout.addWidget(self.w_out)
+        self.verticalLayout_2.addWidget(self.w_out)
 
         self.scrollArea.setWidget(self.scrollAreaWidgetContents)
 
@@ -81,5 +96,6 @@ class Ui_PWSlotUD(object):
         self.b_dxf.setText(
             QCoreApplication.translate("PWSlotUD", u"Define Slot from DXF", None)
         )
+        self.g_wedge.setTitle(QCoreApplication.translate("PWSlotUD", u"Wedge", None))
 
     # retranslateUi
