@@ -9,8 +9,6 @@ from PySide2.QtCore import *
 from PySide2.QtGui import *
 from PySide2.QtWidgets import *
 
-from .....GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect
-
 from pyleecan.GUI.Resources import pyleecan_rc
 
 
@@ -20,7 +18,9 @@ class Ui_SWindCond(object):
             SWindCond.setObjectName(u"SWindCond")
         SWindCond.resize(650, 550)
         SWindCond.setMinimumSize(QSize(650, 550))
-        self.main_layout = QVBoxLayout(SWindCond)
+        self.verticalLayout = QVBoxLayout(SWindCond)
+        self.verticalLayout.setObjectName(u"verticalLayout")
+        self.main_layout = QVBoxLayout()
         self.main_layout.setObjectName(u"main_layout")
         self.horizontalLayout = QHBoxLayout()
         self.horizontalLayout.setObjectName(u"horizontalLayout")
@@ -37,22 +37,6 @@ class Ui_SWindCond(object):
 
         self.horizontalLayout.addWidget(self.c_cond_type)
 
-        self.verticalLayout = QVBoxLayout()
-        self.verticalLayout.setObjectName(u"verticalLayout")
-        self.w_mat_0 = WMatSelect(SWindCond)
-        self.w_mat_0.setObjectName(u"w_mat_0")
-        self.w_mat_0.setMinimumSize(QSize(100, 0))
-
-        self.verticalLayout.addWidget(self.w_mat_0)
-
-        self.w_mat_1 = WMatSelect(SWindCond)
-        self.w_mat_1.setObjectName(u"w_mat_1")
-        self.w_mat_1.setMinimumSize(QSize(100, 0))
-
-        self.verticalLayout.addWidget(self.w_mat_1)
-
-        self.horizontalLayout.addLayout(self.verticalLayout)
-
         self.horizontalSpacer_3 = QSpacerItem(
             40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum
         )
@@ -86,6 +70,8 @@ class Ui_SWindCond(object):
 
         self.main_layout.addLayout(self.horizontalLayout_2)
 
+        self.verticalLayout.addLayout(self.main_layout)
+
         self.retranslateUi(SWindCond)
 
         QMetaObject.connectSlotsByName(SWindCond)
@@ -95,13 +81,13 @@ class Ui_SWindCond(object):
     def retranslateUi(self, SWindCond):
         SWindCond.setWindowTitle(QCoreApplication.translate("SWindCond", u"Form", None))
         self.in_cond_type.setText(
-            QCoreApplication.translate("SWindCond", u"Conductor type :", None)
+            QCoreApplication.translate("SWindCond", u"Coil style", None)
         )
         self.c_cond_type.setItemText(
-            0, QCoreApplication.translate("SWindCond", u"Preformed Rectangular", None)
+            0, QCoreApplication.translate("SWindCond", u"Form wound", None)
         )
         self.c_cond_type.setItemText(
-            1, QCoreApplication.translate("SWindCond", u"Random Round Wire", None)
+            1, QCoreApplication.translate("SWindCond", u"Stranded", None)
         )
 
         self.b_previous.setText(
